@@ -5,6 +5,9 @@ public final class standard extends java.util.ListResourceBundle {
         return new Object[][] {
             { "doclet.All_Modules", "All Modules" },
             { "doclet.All_Packages", "All Packages" },
+            { "doclet.Annotation_Interface_Hierarchy", "Annotation Interface Hierarchy" },
+            { "doclet.Annotation_Interface_Members", "Annotation Interface Elements" },
+            { "doclet.Annotation_Interfaces", "Annotation Interfaces" },
             { "doclet.Annotation_Type_Hierarchy", "Annotation Type Hierarchy" },
             { "doclet.Annotation_Type_Members", "Annotation Type Elements" },
             { "doclet.Annotation_Types", "Annotation Types" },
@@ -44,13 +47,15 @@ public final class standard extends java.util.ListResourceBundle {
             { "doclet.Description_From_Interface", "Description copied from interface:" },
             { "doclet.Detail", "Detail:" },
             { "doclet.Element", "Element" },
+            { "doclet.Element_in", "Element in {0}" },
             { "doclet.Enclosing_Class", "Enclosing class:" },
             { "doclet.Enclosing_Interface", "Enclosing interface:" },
+            { "doclet.Enum_Class_Hierarchy", "Enum Class Hierarchy" },
             { "doclet.Enum_Hierarchy", "Enum Hierarchy" },
+            { "doclet.Enum_constant_in", "Enum constant in {0}" },
             { "doclet.Error_in_grouplist", "Bad -group option: {0} {1}" },
             { "doclet.File_error", "Error reading file: {0}" },
             { "doclet.For_Removal", "For Removal" },
-            { "doclet.Frames", "Frames" },
             { "doclet.Functional_Interface", "Functional Interface:" },
             { "doclet.Functional_Interface_Message", "This is a functional interface and can therefore be used as the assignment target for a lambda expression or method reference." },
             { "doclet.Generated_Docs_Untitled", "Generated Documentation (Untitled)" },
@@ -61,6 +66,7 @@ public final class standard extends java.util.ListResourceBundle {
             { "doclet.Href_Annotation_Title", "annotation in {0}" },
             { "doclet.Href_Class_Or_Interface_Title", "class or interface in {0}" },
             { "doclet.Href_Class_Title", "class in {0}" },
+            { "doclet.Href_Enum_Class_Title", "enum class in {0}" },
             { "doclet.Href_Enum_Title", "enum in {0}" },
             { "doclet.Href_Interface_Title", "interface in {0}" },
             { "doclet.Href_Type_Param_Title", "type parameter in {0}" },
@@ -76,7 +82,6 @@ public final class standard extends java.util.ListResourceBundle {
             { "doclet.Navigation", "Navigation" },
             { "doclet.New_Page", "NewPage" },
             { "doclet.NoFrames_specified", "The --no-frames option is no longer required and may be removed\nin a future release." },
-            { "doclet.No_Frames", "No Frames" },
             { "doclet.No_Non_Deprecated_Classes_To_Document", "No non-deprecated classes found to document." },
             { "doclet.No_Script_Message", "JavaScript is disabled on your browser." },
             { "doclet.None", "None" },
@@ -86,7 +91,9 @@ public final class standard extends java.util.ListResourceBundle {
             { "doclet.Overview", "Overview" },
             { "doclet.Package", "Package" },
             { "doclet.Package_Hierarchies", "Package Hierarchies:" },
+            { "doclet.Record_component_in", "Record component of {0}" },
             { "doclet.ReferencedIn", "Referenced In" },
+            { "doclet.Resource_error", "Error reading resource: {0}" },
             { "doclet.Same_element_name_used", "Element name or pattern used twice: {0}" },
             { "doclet.Search_tag_in", "Search tag in {0}" },
             { "doclet.Skip_navigation_links", "Skip navigation links" },
@@ -109,10 +116,16 @@ public final class standard extends java.util.ListResourceBundle {
             { "doclet.Window_Source_title", "Source code" },
             { "doclet.Window_Split_Index", "{0}-Index" },
             { "doclet.also", "also" },
+            { "doclet.annotation_interface_members", "annotation interface elements" },
+            { "doclet.annotation_interfaces", "annotation interfaces" },
             { "doclet.annotation_type_members", "annotation type elements" },
             { "doclet.annotation_types", "annotation types" },
             { "doclet.build_version", "Standard Doclet version {0}" },
+            { "doclet.footer_specified", "The -footer option is no longer supported and will be ignored.\nIt may be removed in a future release." },
             { "doclet.for_removal", "for removal" },
+            { "doclet.help.annotation_interface.declaration", "Annotation Interface Declaration" },
+            { "doclet.help.annotation_interface.description", "Annotation Interface Description" },
+            { "doclet.help.annotation_interface.intro", "Each annotation interface has its own separate page with the following sections:" },
             { "doclet.help.annotation_type.declaration", "Annotation Type Declaration" },
             { "doclet.help.annotation_type.description", "Annotation Type Description" },
             { "doclet.help.annotation_type.intro", "Each annotation type has its own separate page with the following sections:" },
@@ -124,9 +137,10 @@ public final class standard extends java.util.ListResourceBundle {
             { "doclet.help.class_interface.intro", "Each class, interface, nested class and nested interface has its own separate page. Each of these pages has three sections consisting of a class/interface description, summary tables, and detailed member descriptions:" },
             { "doclet.help.class_interface.subclasses", "Direct Subclasses" },
             { "doclet.help.class_interface.subinterfaces", "All Known Subinterfaces" },
-            { "doclet.help.class_interface.summary", "Each summary entry contains the first sentence from the detailed description for that item. The summary entries are alphabetical, while the detailed descriptions are in the order they appear in the source code. This preserves the logical groupings established by the programmer." },
+            { "doclet.help.class_interface.summary", "The summary entries are alphabetical, while the detailed descriptions are in the order they appear in the source code. This preserves the logical groupings established by the programmer." },
             { "doclet.help.constants.body", "The {0} page lists the static final fields and their values." },
-            { "doclet.help.deprecated.body", "The {0} page lists all of the API that have been deprecated. A deprecated API is not recommended for use, generally due to improvements, and a replacement API is usually given. Deprecated APIs may be removed in future implementations." },
+            { "doclet.help.deprecated.body", "The {0} page lists all of the API that have been deprecated. A deprecated API is not recommended for use, generally due to shortcomings, and a replacement API is usually given. Deprecated APIs may be removed in future implementations." },
+            { "doclet.help.enum.class.intro", "Each enum class has its own separate page with the following sections:" },
             { "doclet.help.enum.declaration", "Enum Declaration" },
             { "doclet.help.enum.definition", "Enum Description" },
             { "doclet.help.enum.intro", "Each enum has its own separate page with the following sections:" },
@@ -135,7 +149,7 @@ public final class standard extends java.util.ListResourceBundle {
             { "doclet.help.index.head", "Index" },
             { "doclet.help.intro", "This API (Application Programming Interface) document has pages corresponding to the items in the navigation bar, described as follows." },
             { "doclet.help.main_heading", "How This API Document Is Organized" },
-            { "doclet.help.module.intro", "Each module has a page that contains a list of its packages, dependencies on other modules, and services, with a summary for each. These page may contain three categories:" },
+            { "doclet.help.module.intro", "Each module has a page that contains a list of its packages, dependencies on other modules, and services, with a summary for each. These pages may contain three categories:" },
             { "doclet.help.overview.modules.body", "The {0} page is the front page of this API document and provides a list of all modules with a summary for each.  This page can also contain an overall description of the set of modules." },
             { "doclet.help.overview.packages.body", "The {0} page is the front page of this API document and provides a list of all packages with a summary for each.  This page can also contain an overall description of the set of packages." },
             { "doclet.help.package.intro", "Each package has a page that contains a list of its classes and interfaces, with a summary for each. These pages may contain six categories:" },
@@ -145,7 +159,8 @@ public final class standard extends java.util.ListResourceBundle {
             { "doclet.help.search.refer", "Refer to {0} for a full description of search features." },
             { "doclet.help.search.spec.title", "the Javadoc Search Specification" },
             { "doclet.help.search.spec.url", "https://docs.oracle.com/en/java/javase/{0}/docs/specs/javadoc/javadoc-search-spec.html" },
-            { "doclet.help.serial_form.body", "Each serializable or externalizable class has a description of its serialization fields and methods. This information is of interest to re-implementors, not to developers using the API. While there is no link in the navigation bar, you can get to this information by going to any serialized class and clicking \"Serialized Form\" in the \"See also\" section of the class description." },
+            { "doclet.help.serial_form.body", "Each serializable or externalizable class has a description of its serialization fields and methods. This information is of interest to those who implement rather than use the API. While there is no link in the navigation bar, you can get to this information by going to any serialized class and clicking \"Serialized Form\" in the \"See Also\" section of the class description." },
+            { "doclet.help.systemProperties.body", "The {0} page lists references to system properties." },
             { "doclet.help.tree.head", "Tree (Class Hierarchy)" },
             { "doclet.help.tree.intro", "There is a {0} page for all packages, plus a hierarchy for each package. Each hierarchy page contains a list of classes and a list of interfaces. Classes are organized by inheritance structure starting with {1}. Interfaces do not inherit from {1}." },
             { "doclet.help.tree.overview", "When viewing the Overview page, clicking on \"Tree\" displays the hierarchy for all packages." },
@@ -170,7 +185,9 @@ public final class standard extends java.util.ListResourceBundle {
             { "doclet.navPackages", "Packages" },
             { "doclet.navProperty", "Property" },
             { "doclet.navServices", "Services" },
+            { "doclet.not.exhaustive", "(not exhaustive)" },
             { "doclet.package", "package" },
+            { "doclet.record_classes", "record classes" },
             { "doclet.see.class_or_package_not_accessible", "Tag {0}: reference not accessible: {1}" },
             { "doclet.see.class_or_package_not_found", "Tag {0}: reference not found: {1}" },
             { "doclet.systemProperties", "System Properties" },
@@ -192,7 +209,7 @@ public final class standard extends java.util.ListResourceBundle {
             { "doclet.usage.doctitle.description", "Include title for the overview page" },
             { "doclet.usage.doctitle.parameters", "<html-code>" },
             { "doclet.usage.excludedocfilessubdir.description", "Exclude any doc-files subdirectories with given name" },
-            { "doclet.usage.excludedocfilessubdir.parameters", "<name>:.." },
+            { "doclet.usage.excludedocfilessubdir.parameters", "<name>:..." },
             { "doclet.usage.footer.description", "Include footer text for each page" },
             { "doclet.usage.footer.parameters", "<html-code>" },
             { "doclet.usage.frames.description", "Enable the use of frames in the generated output" },
@@ -205,6 +222,8 @@ public final class standard extends java.util.ListResourceBundle {
             { "doclet.usage.html5.description", "Generate HTML 5 output. This option is no longer required." },
             { "doclet.usage.javafx.description", "Enable JavaFX functionality" },
             { "doclet.usage.keywords.description", "Include HTML meta tags with package, class and member info" },
+            { "doclet.usage.link-platform-properties.description", "Link to platform documentation URLs declared in properties file at <url>" },
+            { "doclet.usage.link-platform-properties.parameters", "<url>" },
             { "doclet.usage.link.description", "Create links to javadoc output at <url>" },
             { "doclet.usage.link.parameters", "<url>" },
             { "doclet.usage.linkoffline.description", "Link to docs at <url1> using package list at <url2>" },
@@ -214,6 +233,7 @@ public final class standard extends java.util.ListResourceBundle {
             { "doclet.usage.main-stylesheet.parameters", "<file>" },
             { "doclet.usage.no-frames.description", "Disable the use of frames in the generated output (default)" },
             { "doclet.usage.no-module-directories.description", "Do not group files for module documentation into \nmodule-specific directories" },
+            { "doclet.usage.no-platform-links.description", "Do not generate links to the platform documentation" },
             { "doclet.usage.nocomment.description", "Suppress description and tags, generate only declarations" },
             { "doclet.usage.nodeprecated.description", "Do not include @deprecated information" },
             { "doclet.usage.nodeprecatedlist.description", "Do not generate deprecated list" },
@@ -222,7 +242,7 @@ public final class standard extends java.util.ListResourceBundle {
             { "doclet.usage.nonavbar.description", "Do not generate navigation bar" },
             { "doclet.usage.nooverview.description", "Do not generate overview pages" },
             { "doclet.usage.noqualifier.description", "Exclude the list of qualifiers from the output" },
-            { "doclet.usage.noqualifier.parameters", "<name1>:<name2>:.." },
+            { "doclet.usage.noqualifier.parameters", "<name1>:<name2>:..." },
             { "doclet.usage.nosince.description", "Do not include @since information" },
             { "doclet.usage.notimestamp.description", "Do not include hidden time stamp" },
             { "doclet.usage.notree.description", "Do not generate class hierarchy" },
