@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2005, 2018, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2005, 2020, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -27,6 +27,7 @@ package sun.jvm.hotspot;
 import java.io.BufferedOutputStream;
 import java.io.BufferedReader;
 import java.io.ByteArrayOutputStream;
+import java.io.File;
 import java.io.FileInputStream;
 import java.io.FileOutputStream;
 import java.io.IOException;
@@ -50,7 +51,6 @@ import sun.jvm.hotspot.debugger.Address;
 import sun.jvm.hotspot.debugger.OopHandle;
 import sun.jvm.hotspot.classfile.ClassLoaderDataGraph;
 import sun.jvm.hotspot.memory.FileMapInfo;
-import sun.jvm.hotspot.memory.SymbolTable;
 import sun.jvm.hotspot.memory.SystemDictionary;
 import sun.jvm.hotspot.memory.Universe;
 import sun.jvm.hotspot.gc.shared.CollectedHeap;
@@ -75,11 +75,14 @@ import sun.jvm.hotspot.runtime.JavaVFrame;
 import sun.jvm.hotspot.runtime.Threads;
 import sun.jvm.hotspot.runtime.VM;
 import sun.jvm.hotspot.tools.ObjectHistogram;
+import sun.jvm.hotspot.tools.JMap;
 import sun.jvm.hotspot.tools.PMap;
 import sun.jvm.hotspot.tools.PStack;
 import sun.jvm.hotspot.tools.StackTrace;
+import sun.jvm.hotspot.tools.SysPropsDumper;
 import sun.jvm.hotspot.tools.jcore.ClassDump;
 import sun.jvm.hotspot.tools.jcore.ClassFilter;
+import sun.jvm.hotspot.tools.jcore.ClassWriter;
 import sun.jvm.hotspot.types.CIntegerType;
 import sun.jvm.hotspot.types.Field;
 import sun.jvm.hotspot.types.Type;
@@ -101,9 +104,6 @@ import sun.jvm.hotspot.utilities.ReversePtrs;
 import sun.jvm.hotspot.utilities.ReversePtrsAnalysis;
 import sun.jvm.hotspot.utilities.RobustOopDeterminator;
 import sun.jvm.hotspot.utilities.SystemDictionaryHelper;
-import sun.jvm.hotspot.utilities.soql.JSJavaFactory;
-import sun.jvm.hotspot.utilities.soql.JSJavaFactoryImpl;
-import sun.jvm.hotspot.utilities.soql.JSJavaScriptEngine;
 
 public class CommandProcessor {
 
@@ -125,7 +125,7 @@ public class CommandProcessor {
     }
 
     public static class NonBootFilter implements ClassFilter {
-        private HashMap emitted = new HashMap();
+        private HashMap<Symbol, InstanceKlass> emitted = new HashMap<>();
         public boolean canInclude(InstanceKlass kls) {
             if (kls.getClassLoader() == null) return false;
             if (emitted.get(kls.getName()) != null) {
@@ -153,7 +153,7 @@ public class CommandProcessor {
             return t;
         }
 
-        void add(String s, ArrayList t) {
+        void add(String s, ArrayList<String> t) {
             if (s.length() > 0) {
                 t.add(s);
             }
@@ -164,7 +164,7 @@ public class CommandProcessor {
 
             // check for quoting
             int quote = cmd.indexOf('"');
-            ArrayList t = new ArrayList();
+            ArrayList<String> t = new ArrayList<>();
             if (quote != -1) {
                 while (cmd.length() > 0) {
                     if (quote != -1) {
@@ -537,7 +537,8 @@ public class CommandProcessor {
                 // Not an address
                 boolean all = name.equals("-a");
                 Threads threads = VM.getVM().getThreads();
-                for (JavaThread thread = threads.first(); thread != null; thread = thread.next()) {
+                for (int i = 0; i < threads.getNumberOfThreads(); i++) {
+                    JavaThread thread = threads.getJavaThreadAt(i);
                     ByteArrayOutputStream bos = new ByteArrayOutputStream();
                     thread.printThreadIDOn(new PrintStream(bos));
                     if (all || bos.toString().equals(name)) {
@@ -628,35 +629,6 @@ public class CommandProcessor {
                 }
             }
         },
-        new Command("symboltable", "symboltable name", false) {
-            public void doit(Tokens t) {
-                if (t.countTokens() != 1) {
-                    usage();
-                } else {
-                    out.println(SymbolTable.getTheTable().probe(t.nextToken()));
-                }
-            }
-        },
-        new Command("symboldump", "symboldump", false) {
-            public void doit(Tokens t) {
-                SymbolTable theTable = SymbolTable.getTheTable();
-                theTable.symbolsDo(new SymbolTable.SymbolVisitor() {
-                        public void visit(Symbol sym) {
-                            sym.printValueOn(out);
-                            out.println();
-                        }
-                    });
-                CompactHashTable sharedTable = theTable.getSharedTable();
-                if (sharedTable != null) {
-                    sharedTable.symbolsDo(new CompactHashTable.SymbolVisitor() {
-                            public void visit(Symbol sym) {
-                                sym.printValueOn(out);
-                                out.println();
-                            }
-                        });
-                }
-            }
-        },
         new Command("flags", "flags [ flag | -nd ]", false) {
             public void doit(Tokens t) {
                 int tokens = t.countTokens();
@@ -679,11 +651,11 @@ public class CommandProcessor {
                             VM.Flag flag = flags[f];
                             if (name == null || flag.getName().equals(name)) {
 
-                                if (nonDefault && flag.getOrigin() == 0) {
+                                if (nonDefault && (flag.getOrigin() == VM.Flags_DEFAULT)) {
                                     // only print flags which aren't their defaults
                                     continue;
                                 }
-                                out.println(flag.getName() + " = " + flag.getValue() + " " + flag.getOrigin());
+                                out.println(flag.getName() + " = " + flag.getValue() + " " + flag.getOriginString());
                                 printed = true;
                             }
                         }
@@ -707,7 +679,7 @@ public class CommandProcessor {
                 } else if (tokens == 0) {
                     out.println("Available commands:");
                     Object[] keys = commands.keySet().toArray();
-                    Arrays.sort(keys, new Comparator() {
+                    Arrays.sort(keys, new Comparator<>() {
                              public int compare(Object o1, Object o2) {
                                  return o1.toString().compareTo(o2.toString());
                              }
@@ -928,7 +900,8 @@ public class CommandProcessor {
                     String name = t.nextToken();
                     boolean all = name.equals("-a");
                     Threads threads = VM.getVM().getThreads();
-                    for (JavaThread thread = threads.first(); thread != null; thread = thread.next()) {
+                    for (int i = 0; i < threads.getNumberOfThreads(); i++) {
+                        JavaThread thread = threads.getJavaThreadAt(i);
                         ByteArrayOutputStream bos = new ByteArrayOutputStream();
                         thread.printThreadIDOn(new PrintStream(bos));
                         if (all || bos.toString().equals(name)) {
@@ -957,7 +930,8 @@ public class CommandProcessor {
                     String name = t.nextToken();
                     boolean all = name.equals("-a");
                     Threads threads = VM.getVM().getThreads();
-                    for (JavaThread thread = threads.first(); thread != null; thread = thread.next()) {
+                    for (int i = 0; i < threads.getNumberOfThreads(); i++) {
+                        JavaThread thread = threads.getJavaThreadAt(i);
                         ByteArrayOutputStream bos = new ByteArrayOutputStream();
                         thread.printThreadIDOn(new PrintStream(bos));
                         if (all || bos.toString().equals(name)) {
@@ -984,7 +958,8 @@ public class CommandProcessor {
                     String name = t.nextToken();
                     boolean all = name.equals("-a");
                     Threads threads = VM.getVM().getThreads();
-                    for (JavaThread thread = threads.first(); thread != null; thread = thread.next()) {
+                    for (int i = 0; i < threads.getNumberOfThreads(); i++) {
+                        JavaThread thread = threads.getJavaThreadAt(i);
                         ByteArrayOutputStream bos = new ByteArrayOutputStream();
                         thread.printThreadIDOn(new PrintStream(bos));
                         if (all || bos.toString().equals(name)) {
@@ -1015,8 +990,8 @@ public class CommandProcessor {
                 // be read back.
                 Iterator i = agent.getTypeDataBase().getTypes();
                 // Make sure the types are emitted in an order than can be read back in
-                HashSet emitted = new HashSet();
-                Stack pending = new Stack();
+                HashSet<String> emitted = new HashSet<>();
+                Stack<Type> pending = new Stack<>();
                 while (i.hasNext()) {
                     Type n = (Type)i.next();
                     if (emitted.contains(n.getName())) {
@@ -1227,7 +1202,7 @@ public class CommandProcessor {
                 }
             }
         },
-        new Command("intConstant", "intConstant [ name [ value ] ]", true) {
+        new Command("intConstant", "intConstant [ name [ value ] ]", false) {
             public void doit(Tokens t) {
                 if (t.countTokens() != 1 && t.countTokens() != 0 && t.countTokens() != 2) {
                     usage();
@@ -1250,7 +1225,7 @@ public class CommandProcessor {
                 }
             }
         },
-        new Command("longConstant", "longConstant [ name [ value ] ]", true) {
+        new Command("longConstant", "longConstant [ name [ value ] ]", false) {
             public void doit(Tokens t) {
                 if (t.countTokens() != 1 && t.countTokens() != 0 && t.countTokens() != 2) {
                     usage();
@@ -1273,7 +1248,7 @@ public class CommandProcessor {
                 }
             }
         },
-        new Command("field", "field [ type [ name fieldtype isStatic offset address ] ]", true) {
+        new Command("field", "field [ type [ name fieldtype isStatic offset address ] ]", false) {
             public void doit(Tokens t) {
                 if (t.countTokens() != 1 && t.countTokens() != 0 && t.countTokens() != 6) {
                     usage();
@@ -1345,7 +1320,7 @@ public class CommandProcessor {
                 }
             }
         },
-        new Command("type", "type [ type [ name super isOop isInteger isUnsigned size ] ]", true) {
+        new Command("type", "type [ type [ name super isOop isInteger isUnsigned size ] ]", false) {
             public void doit(Tokens t) {
                 if (t.countTokens() != 1 && t.countTokens() != 0 && t.countTokens() != 6) {
                     usage();
@@ -1411,8 +1386,8 @@ public class CommandProcessor {
                 } else {
                     Iterator i = agent.getTypeDataBase().getTypes();
                     // Make sure the types are emitted in an order than can be read back in
-                    HashSet emitted = new HashSet();
-                    Stack pending = new Stack();
+                    HashSet<String> emitted = new HashSet<>();
+                    Stack<Type> pending = new Stack<>();
                     while (i.hasNext()) {
                         Type n = (Type)i.next();
                         if (emitted.contains(n.getName())) {
@@ -1467,7 +1442,8 @@ public class CommandProcessor {
                 final long stride = VM.getVM().getAddressSize();
                 if (type.equals("threads")) {
                     Threads threads = VM.getVM().getThreads();
-                    for (JavaThread thread = threads.first(); thread != null; thread = thread.next()) {
+                    for (int i = 0; i < threads.getNumberOfThreads(); i++) {
+                        JavaThread thread = threads.getJavaThreadAt(i);
                         Address base = thread.getStackBase();
                         Address end = thread.getLastJavaSP();
                         if (end == null) continue;
@@ -1591,7 +1567,8 @@ public class CommandProcessor {
                     String name = t.nextToken();
                     Threads threads = VM.getVM().getThreads();
                     boolean all = name.equals("-a");
-                    for (JavaThread thread = threads.first(); thread != null; thread = thread.next()) {
+                    for (int i = 0; i < threads.getNumberOfThreads(); i++) {
+                        JavaThread thread = threads.getJavaThreadAt(i);
                         ByteArrayOutputStream bos = new ByteArrayOutputStream();
                         thread.printThreadIDOn(new PrintStream(bos));
                         if (all || bos.toString().equals(name)) {
@@ -1620,7 +1597,8 @@ public class CommandProcessor {
                     String name = t.nextToken();
                     Threads threads = VM.getVM().getThreads();
                     boolean all = name.equals("-a");
-                    for (JavaThread thread = threads.first(); thread != null; thread = thread.next()) {
+                    for (int i = 0; i < threads.getNumberOfThreads(); i++) {
+                        JavaThread thread = threads.getJavaThreadAt(i);
                         ByteArrayOutputStream bos = new ByteArrayOutputStream();
                         thread.printThreadIDOn(new PrintStream(bos));
                         if (all || bos.toString().equals(name)) {
@@ -1643,7 +1621,8 @@ public class CommandProcessor {
                     usage();
                 } else {
                     Threads threads = VM.getVM().getThreads();
-                    for (JavaThread thread = threads.first(); thread != null; thread = thread.next()) {
+                    for (int i = 0; i < threads.getNumberOfThreads(); i++) {
+                        JavaThread thread = threads.getJavaThreadAt(i);
                         thread.printThreadIDOn(out);
                         out.println(" " + thread.getThreadName());
                         thread.printInfoOn(out);
@@ -1658,10 +1637,11 @@ public class CommandProcessor {
                 if (t.countTokens() != 0) {
                     usage();
                 } else {
-                    ArrayList nmethods = new ArrayList();
+                    ArrayList<NMethod> nmethods = new ArrayList<>();
                     Threads threads = VM.getVM().getThreads();
                     HTMLGenerator gen = new HTMLGenerator(false);
-                    for (JavaThread thread = threads.first(); thread != null; thread = thread.next()) {
+                    for (int i = 0; i < threads.getNumberOfThreads(); i++) {
+                        JavaThread thread = threads.getJavaThreadAt(i);
                         try {
                             for (JavaVFrame vf = thread.getLastJavaVFrameDbg(); vf != null; vf = vf.javaSender()) {
                                 if (vf instanceof CompiledVFrame) {
@@ -1723,11 +1703,134 @@ public class CommandProcessor {
                 }
             }
         },
+        new Command("dumpclass", "dumpclass {address | name} [directory]", false) {
+            public void doit(Tokens t) {
+                int tokenCount = t.countTokens();
+                if (tokenCount != 1 && tokenCount != 2) {
+                    usage();
+                    return;
+                }
+
+                /* Find the InstanceKlass for specified class name or class address. */
+                InstanceKlass ik = null;
+                String classname = t.nextToken();
+                if (classname.startsWith("0x")) {
+                    // treat it as address
+                    VM vm = VM.getVM();
+                    Address addr = vm.getDebugger().parseAddress(classname);
+                    Metadata metadata = Metadata.instantiateWrapperFor(addr.addOffsetTo(0));
+                    if (metadata instanceof InstanceKlass) {
+                        ik = (InstanceKlass) metadata;
+                    } else {
+                        System.out.println("Specified address is not an InstanceKlass");
+                        return;
+                    }
+                } else {
+                    ik = SystemDictionaryHelper.findInstanceKlass(classname);
+                    if (ik == null) {
+                        System.out.println("class not found: " + classname);
+                        return;
+                    }
+                }
+
+                /* Compute filename for class. */
+                StringBuffer buf = new StringBuffer();
+                if (tokenCount > 1) {
+                    buf.append(t.nextToken());
+                } else {
+                    buf.append('.');
+                }
+                buf.append(File.separatorChar);
+                buf.append(ik.getName().asString().replace('/', File.separatorChar));
+                buf.append(".class");
+                String fileName = buf.toString();
+                File file = new File(fileName);
+
+                /* Dump the class file. */
+                try {
+                    int index = fileName.lastIndexOf(File.separatorChar);
+                    File dir = new File(fileName.substring(0, index));
+                    dir.mkdirs();
+                    try (FileOutputStream fos = new FileOutputStream(file)) {
+                        ClassWriter cw = new ClassWriter(ik, fos);
+                        cw.write();
+                    }
+                } catch (Exception e) {
+                    err.println("Error: " + e);
+                    if (verboseExceptions) {
+                        e.printStackTrace(err);
+                    }
+                }
+            }
+        },
+        new Command("sysprops", "sysprops", false) {
+            public void doit(Tokens t) {
+                if (t.countTokens() != 0) {
+                    usage();
+                    return;
+                }
+                SysPropsDumper sysProps = new SysPropsDumper();
+                sysProps.run();
+            }
+        },
+        new Command("dumpheap", "dumpheap [filename]", false) {
+            public void doit(Tokens t) {
+                if (t.countTokens() > 1) {
+                    usage();
+                } else {
+                    JMap jmap = new JMap();
+                    String filename;
+                    if (t.countTokens() == 1) {
+                        filename = t.nextToken();
+                    } else {
+                        filename = "heap.bin";;
+                    }
+                    try {
+                        jmap.writeHeapHprofBin(filename);
+                    } catch (Exception e) {
+                        err.println("Error: " + e);
+                        if (verboseExceptions) {
+                            e.printStackTrace(err);
+                        }
+                    }
+                }
+            }
+        },
+        new Command("class", "class name", false) {
+            public void doit(Tokens t) {
+                if (t.countTokens() != 1) {
+                    usage();
+                    return;
+                }
+                String classname = t.nextToken();
+                InstanceKlass ik = SystemDictionaryHelper.findInstanceKlass(classname);
+                if (ik == null) {
+                    System.out.println("class not found: " + classname);
+                } else {
+                    System.out.println(ik.getName().asString() + " @" + ik.getAddress());
+                }
+            }
+        },
+        new Command("classes", "classes", false) {
+            public void doit(Tokens t) {
+                if (t.countTokens() != 0) {
+                    usage();
+                    return;
+                }
+                ClassLoaderDataGraph cldg = VM.getVM().getClassLoaderDataGraph();
+                cldg.classesDo(new ClassLoaderDataGraph.ClassVisitor() {
+                        public void visit(Klass k) {
+                            System.out.println(k.getName().asString() + " @" + k.getAddress());
+                        }
+                    }
+                );
+            }
+        },
     };
 
     private boolean verboseExceptions = false;
-    private ArrayList history = new ArrayList();
-    private HashMap commands = new HashMap();
+    private ArrayList<String> history = new ArrayList<>();
+    private HashMap<String, Command> commands = new HashMap<>();
     private boolean doEcho = false;
 
     private Command findCommand(String key) {
@@ -1740,7 +1843,6 @@ public class CommandProcessor {
 
     private DebuggerInterface debugger;
     private HotSpotAgent agent;
-    private JSJavaScriptEngine jsengine;
     private BufferedReader in;
     private PrintStream out;
     private PrintStream err;
@@ -1752,62 +1854,7 @@ public class CommandProcessor {
 
     // called after debuggee attach
     private void postAttach() {
-        // create JavaScript engine and start it
-        try {
-            jsengine = new JSJavaScriptEngine() {
-                        private ObjectReader reader = new ObjectReader();
-                        private JSJavaFactory factory = new JSJavaFactoryImpl();
-                        public ObjectReader getObjectReader() {
-                            return reader;
-                        }
-                        public JSJavaFactory getJSJavaFactory() {
-                            return factory;
-                        }
-                        protected void quit() {
-                            debugger.detach();
-                            quit = true;
-                        }
-                        protected BufferedReader getInputReader() {
-                            return in;
-                        }
-                        protected PrintStream getOutputStream() {
-                            return out;
-                        }
-                        protected PrintStream getErrorStream() {
-                            return err;
-                        }
-                   };
-            try {
-                jsengine.defineFunction(this,
-                     this.getClass().getMethod("registerCommand",
-                                new Class[] {
-                                     String.class, String.class, String.class
-                                }));
-            } catch (NoSuchMethodException exp) {
-                  // should not happen, see below...!!
-                  exp.printStackTrace();
-            }
-            jsengine.start();
-        }
-        catch (Exception ex) {
-            System.out.println("Warning! JS Engine can't start, some commands will not be available.");
-            if (verboseExceptions) {
-                ex.printStackTrace(out);
-            }
-        }
-    }
-
-    public void registerCommand(String cmd, String usage, final String func) {
-        commands.put(cmd, new Command(cmd, usage, false) {
-                              public void doit(Tokens t) {
-                                  final int len = t.countTokens();
-                                  Object[] args = new Object[len];
-                                  for (int i = 0; i < len; i++) {
-                                      args[i] = t.nextToken();
-                                  }
-                                  jsengine.call(func, args);
-                              }
-                          });
+        // nothing for now..
     }
 
     public void setOutput(PrintStream o) {
