@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -81,25 +77,9 @@ public class FormatData_es_US extends ListResourceBundle {
             };
         final String[] metaValue_QuarterNames = new String[] {
                "1.er trimestre",
-               "2\u00ba. trimestre",
+               "2.\u00ba trimestre",
                "3.er trimestre",
-               "4o. trimestre",
-            };
-        final String[] metaValue_QuarterAbbreviations = new String[] {
-               "1er. trim.",
-               "2\u00ba. trim.",
-               "3er. trim.",
-               "4\u00ba trim.",
-            };
-        final String[] metaValue_QuarterNarrows = new String[] {
-               "1T",
-               "2T",
-               "3T",
-               "4T",
-            };
-        final String[] metaValue_AmPmMarkers = new String[] {
-               "a.\u00a0m.",
-               "p.\u00a0m.",
+               "4.\u00ba trimestre",
             };
         final String[] metaValue_TimePatterns = new String[] {
                "h:mm:ss a zzzz",
@@ -107,40 +87,40 @@ public class FormatData_es_US extends ListResourceBundle {
                "h:mm:ss a",
                "h:mm a",
             };
-        final String[] metaValue_java_time_buddhist_DatePatterns = new String[] {
-               "EEEE, d 'de' MMMM 'de' y G",
-               "d 'de' MMMM 'de' y G",
-               "d MMM, y G",
-               "dd/MM/yy GGGGG",
-            };
-        final String[] metaValue_buddhist_DatePatterns = new String[] {
-               "EEEE, d 'de' MMMM 'de' y GGGG",
-               "d 'de' MMMM 'de' y GGGG",
-               "d MMM, y GGGG",
-               "dd/MM/yy G",
-            };
         final Object[][] data = new Object[][] {
-            { "islamic.QuarterAbbreviations", metaValue_QuarterAbbreviations },
-            { "japanese.AmPmMarkers", metaValue_AmPmMarkers },
-            { "islamic.AmPmMarkers", metaValue_AmPmMarkers },
-            { "AmPmMarkers", metaValue_AmPmMarkers },
-            { "java.time.japanese.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
-            { "standalone.QuarterAbbreviations", metaValue_QuarterAbbreviations },
+            { "roc.DayNarrows", metaValue_DayNarrows },
+            { "islamic.QuarterNames", metaValue_QuarterNames },
+            { "short.CompactNumberPatterns",
+                new String[] {
+                    "",
+                    "",
+                    "",
+                    "{one:0\u00a0K other:0\u00a0K}",
+                    "{one:00\u00a0K other:00\u00a0K}",
+                    "{one:000\u00a0K other:000\u00a0K}",
+                    "",
+                    "",
+                    "",
+                    "{one:0\u00a0B other:0\u00a0B}",
+                    "{one:00\u00a0B other:00\u00a0B}",
+                    "{one:000\u00a0B other:000\u00a0B}",
+                    "{one:0\u00a0T other:0\u00a0T}",
+                    "{one:00\u00a0T other:00\u00a0T}",
+                    "{one:000\u00a0T other:000\u00a0T}",
+                }
+            },
             { "roc.QuarterNames", metaValue_QuarterNames },
             { "TimePatterns", metaValue_TimePatterns },
+            { "DatePatterns",
+                new String[] {
+                    "EEEE, d 'de' MMMM 'de' y",
+                    "d 'de' MMMM 'de' y",
+                    "d MMM y",
+                    "d/M/y",
+                }
+            },
             { "islamic.DayNarrows", metaValue_DayNarrows },
-            { "japanese.QuarterAbbreviations", metaValue_QuarterAbbreviations },
-            { "japanese.TimePatterns", metaValue_TimePatterns },
-            { "abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
-            { "japanese.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
-            { "buddhist.narrow.AmPmMarkers", metaValue_AmPmMarkers },
-            { "buddhist.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
-            { "islamic.QuarterNames", metaValue_QuarterNames },
-            { "QuarterNarrows", metaValue_QuarterNarrows },
-            { "islamic.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
-            { "standalone.QuarterNarrows", metaValue_QuarterNarrows },
-            { "roc.QuarterNarrows", metaValue_QuarterNarrows },
-            { "java.time.islamic.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
+            { "islamic.TimePatterns", metaValue_TimePatterns },
             { "DateTimePatterns",
                 new String[] {
                     "{1} 'a' 'las' {0}",
@@ -162,55 +142,12 @@ public class FormatData_es_US extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
-            { "japanese.DatePatterns", metaValue_buddhist_DatePatterns },
-            { "buddhist.AmPmMarkers", metaValue_AmPmMarkers },
-            { "field.dayperiod", "a.\u00a0m./p.\u00a0m." },
-            { "japanese.QuarterNames", metaValue_QuarterNames },
-            { "buddhist.QuarterAbbreviations", metaValue_QuarterAbbreviations },
-            { "japanese.QuarterNarrows", metaValue_QuarterNarrows },
-            { "calendarname.roc", "calendario minguo" },
-            { "islamic.DatePatterns", metaValue_buddhist_DatePatterns },
-            { "roc.QuarterAbbreviations", metaValue_QuarterAbbreviations },
-            { "buddhist.DatePatterns", metaValue_buddhist_DatePatterns },
-            { "DayNarrows", metaValue_DayNarrows },
-            { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
-            { "buddhist.QuarterNames", metaValue_QuarterNames },
-            { "islamic.QuarterNarrows", metaValue_QuarterNarrows },
-            { "roc.DayNarrows", metaValue_DayNarrows },
-            { "roc.AmPmMarkers", metaValue_AmPmMarkers },
-            { "java.time.roc.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
-            { "java.time.buddhist.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
-            { "short.CompactNumberPatterns",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "{one:0\u00a0K other:0\u00a0K}",
-                    "{one:00\u00a0K other:00\u00a0K}",
-                    "{one:000\u00a0K other:000\u00a0K}",
-                    "",
-                    "",
-                    "",
-                    "{one:0\u00a0B other:0\u00a0B}",
-                    "{one:00\u00a0B other:00\u00a0B}",
-                    "{one:000\u00a0B other:000\u00a0B}",
-                    "{one:0\u00a0T other:0\u00a0T}",
-                    "{one:00\u00a0T other:00\u00a0T}",
-                    "{one:000\u00a0T other:000\u00a0T}",
-                }
-            },
-            { "DatePatterns",
-                new String[] {
-                    "EEEE, d 'de' MMMM 'de' y",
-                    "d 'de' MMMM 'de' y",
-                    "d MMM y",
-                    "d/M/y",
-                }
-            },
-            { "islamic.TimePatterns", metaValue_TimePatterns },
             { "buddhist.TimePatterns", metaValue_TimePatterns },
+            { "japanese.TimePatterns", metaValue_TimePatterns },
             { "latn.NumberPatterns",
                 new String[] {
                     "#,##0.###",
@@ -239,20 +176,21 @@ public class FormatData_es_US extends ListResourceBundle {
                 }
             },
             { "buddhist.DayNarrows", metaValue_DayNarrows },
-            { "buddhist.QuarterNarrows", metaValue_QuarterNarrows },
+            { "DayNarrows", metaValue_DayNarrows },
             { "japanese.DayNarrows", metaValue_DayNarrows },
             { "QuarterNames", metaValue_QuarterNames },
             { "roc.TimePatterns", metaValue_TimePatterns },
-            { "QuarterAbbreviations", metaValue_QuarterAbbreviations },
+            { "QuarterAbbreviations", metaValue_QuarterNames },
+            { "buddhist.QuarterNames", metaValue_QuarterNames },
             { "standalone.QuarterNames",
                 new String[] {
                     "1.er trimestre",
                     "2\u00ba. trimestre",
                     "3.er trimestre",
-                    "4\u00ba trimestre",
+                    "4.\u00ba trimestre",
                 }
             },
-            { "roc.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
+            { "japanese.QuarterNames", metaValue_QuarterNames },
         };
         return data;
     }
