@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -136,10 +132,30 @@ public class FormatData_th extends ListResourceBundle {
         final String[] metaValue_AmPmMarkers = new String[] {
                "\u0e01\u0e48\u0e2d\u0e19\u0e40\u0e17\u0e35\u0e48\u0e22\u0e07",
                "\u0e2b\u0e25\u0e31\u0e07\u0e40\u0e17\u0e35\u0e48\u0e22\u0e07",
+               "\u0e40\u0e17\u0e35\u0e48\u0e22\u0e07\u0e04\u0e37\u0e19",
+               "\u0e40\u0e17\u0e35\u0e48\u0e22\u0e07",
+               "\u0e43\u0e19\u0e15\u0e2d\u0e19\u0e40\u0e0a\u0e49\u0e32",
+               "",
+               "\u0e43\u0e19\u0e15\u0e2d\u0e19\u0e1a\u0e48\u0e32\u0e22",
+               "\u0e1a\u0e48\u0e32\u0e22",
+               "\u0e43\u0e19\u0e15\u0e2d\u0e19\u0e40\u0e22\u0e47\u0e19",
+               "\u0e04\u0e48\u0e33",
+               "\u0e01\u0e25\u0e32\u0e07\u0e04\u0e37\u0e19",
+               "",
             };
         final String[] metaValue_narrow_AmPmMarkers = new String[] {
                "a",
                "p",
+               "\u0e40\u0e17\u0e35\u0e48\u0e22\u0e07\u0e04\u0e37\u0e19",
+               "\u0e40\u0e17\u0e35\u0e48\u0e22\u0e07",
+               "\u0e40\u0e0a\u0e49\u0e32",
+               "",
+               "\u0e40\u0e17\u0e35\u0e48\u0e22\u0e07",
+               "\u0e1a\u0e48\u0e32\u0e22",
+               "\u0e40\u0e22\u0e47\u0e19",
+               "\u0e04\u0e48\u0e33",
+               "\u0e01\u0e25\u0e32\u0e07\u0e04\u0e37\u0e19",
+               "",
             };
         final String[] metaValue_Eras = new String[] {
                "\u0e01\u0e48\u0e2d\u0e19 \u0e04.\u0e28.",
@@ -151,6 +167,12 @@ public class FormatData_th extends ListResourceBundle {
                "HH:mm:ss",
                "HH:mm",
             };
+        final String[] metaValue_DateTimePatterns = new String[] {
+               "{1} {0}",
+               "{1} {0}",
+               "{1} {0}",
+               "{1} {0}",
+            };
         final String[] metaValue_buddhist_QuarterNarrows = new String[] {
                "1",
                "2",
@@ -231,17 +253,11 @@ public class FormatData_th extends ListResourceBundle {
                     "\u0e04\u0e23\u0e34\u0e2a\u0e15\u0e4c\u0e28\u0e31\u0e01\u0e23\u0e32\u0e0a",
                 }
             },
+            { "roc.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "islamic.DayNames", metaValue_DayNames },
             { "buddhist.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "buddhist.MonthNames", metaValue_MonthNames },
-            { "DateTimePatterns",
-                new String[] {
-                    "{1} {0}",
-                    "{1} {0}",
-                    "{1} {0}",
-                    "{1} {0}",
-                }
-            },
+            { "DateTimePatterns", metaValue_DateTimePatterns },
             { "narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "latn.NumberElements",
                 new String[] {
@@ -256,6 +272,8 @@ public class FormatData_th extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "MonthNarrows", metaValue_MonthAbbreviations },
@@ -291,6 +309,7 @@ public class FormatData_th extends ListResourceBundle {
                     "",
                 }
             },
+            { "japanese.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "calendarname.roc", "\u0e1b\u0e0f\u0e34\u0e17\u0e34\u0e19\u0e44\u0e15\u0e49\u0e2b\u0e27\u0e31\u0e19" },
             { "islamic.DatePatterns",
                 new String[] {
@@ -308,13 +327,6 @@ public class FormatData_th extends ListResourceBundle {
             { "field.second", "\u0e27\u0e34\u0e19\u0e32\u0e17\u0e35" },
             { "DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNarrows", metaValue_DayNarrows },
-            { "NumberPatterns",
-                new String[] {
-                    "#,##0.###",
-                    "\u00a4#,##0.00",
-                    "#,##0%",
-                }
-            },
             { "roc.DatePatterns",
                 new String[] {
                     "EEEE\u0e17\u0e35\u0e48 d MMMM \u0e1b\u0e35GGGG\u0e17\u0e35\u0e48 y",
@@ -325,6 +337,7 @@ public class FormatData_th extends ListResourceBundle {
             },
             { "calendarname.islamic", "\u0e1b\u0e0f\u0e34\u0e17\u0e34\u0e19\u0e2d\u0e34\u0e2a\u0e25\u0e32\u0e21" },
             { "java.time.roc.long.Eras", metaValue_java_time_roc_long_Eras },
+            { "DayPeriodRules", "midnight:00:00;noon:12:00;evening2:18:00-21:00;night1:21:00-06:00;afternoon1:12:00-13:00;morning1:06:00-12:00;afternoon2:13:00-16:00;evening1:16:00-18:00" },
             { "java.time.roc.narrow.Eras", metaValue_java_time_roc_long_Eras },
             { "japanese.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "buddhist.TimePatterns", metaValue_TimePatterns },
@@ -335,18 +348,18 @@ public class FormatData_th extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0 \u0e1e\u0e31\u0e19",
-                    "0 \u0e2b\u0e21\u0e37\u0e48\u0e19",
-                    "0 \u0e41\u0e2a\u0e19",
-                    "0 \u0e25\u0e49\u0e32\u0e19",
-                    "00 \u0e25\u0e49\u0e32\u0e19",
-                    "000 \u0e25\u0e49\u0e32\u0e19",
-                    "0 \u0e1e\u0e31\u0e19\u0e25\u0e49\u0e32\u0e19",
-                    "0 \u0e2b\u0e21\u0e37\u0e48\u0e19\u0e25\u0e49\u0e32\u0e19",
-                    "0 \u0e41\u0e2a\u0e19\u0e25\u0e49\u0e32\u0e19",
-                    "0 \u0e25\u0e49\u0e32\u0e19\u0e25\u0e49\u0e32\u0e19",
-                    "00 \u0e25\u0e49\u0e32\u0e19\u0e25\u0e49\u0e32\u0e19",
-                    "000 \u0e25\u0e49\u0e32\u0e19\u0e25\u0e49\u0e32\u0e19",
+                    "{other:0' '\u0e1e\u0e31\u0e19}",
+                    "{other:0' '\u0e2b\u0e21\u0e37\u0e48\u0e19}",
+                    "{other:0' '\u0e41\u0e2a\u0e19}",
+                    "{other:0' '\u0e25\u0e49\u0e32\u0e19}",
+                    "{other:00' '\u0e25\u0e49\u0e32\u0e19}",
+                    "{other:000' '\u0e25\u0e49\u0e32\u0e19}",
+                    "{other:0' '\u0e1e\u0e31\u0e19\u0e25\u0e49\u0e32\u0e19}",
+                    "{other:0' '\u0e2b\u0e21\u0e37\u0e48\u0e19\u0e25\u0e49\u0e32\u0e19}",
+                    "{other:0' '\u0e41\u0e2a\u0e19\u0e25\u0e49\u0e32\u0e19}",
+                    "{other:0' '\u0e25\u0e49\u0e32\u0e19\u0e25\u0e49\u0e32\u0e19}",
+                    "{other:00' '\u0e25\u0e49\u0e32\u0e19\u0e25\u0e49\u0e32\u0e19}",
+                    "{other:000' '\u0e25\u0e49\u0e32\u0e19\u0e25\u0e49\u0e32\u0e19}",
                 }
             },
             { "roc.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
@@ -428,18 +441,18 @@ public class FormatData_th extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0K",
-                    "00K",
-                    "000K",
-                    "0M",
-                    "00M",
-                    "000M",
-                    "0B",
-                    "00B",
-                    "000B",
-                    "0T",
-                    "00T",
-                    "000T",
+                    "{other:0K}",
+                    "{other:00K}",
+                    "{other:000K}",
+                    "{other:0M}",
+                    "{other:00M}",
+                    "{other:000M}",
+                    "{other:0B}",
+                    "{other:00B}",
+                    "{other:000B}",
+                    "{other:0T}",
+                    "{other:00T}",
+                    "{other:000T}",
                 }
             },
             { "calendarname.gregorian", metaValue_calendarname_gregorian },
@@ -455,6 +468,7 @@ public class FormatData_th extends ListResourceBundle {
             },
             { "buddhist.DayAbbreviations", metaValue_DayAbbreviations },
             { "islamic.TimePatterns", metaValue_TimePatterns },
+            { "japanese.DateTimePatterns", metaValue_DateTimePatterns },
             { "MonthAbbreviations", metaValue_MonthAbbreviations },
             { "standalone.DayNames", metaValue_DayNames },
             { "field.hour", "\u0e0a\u0e31\u0e48\u0e27\u0e42\u0e21\u0e07" },
@@ -478,6 +492,14 @@ public class FormatData_th extends ListResourceBundle {
             { "islamic.narrow.Eras", metaValue_java_time_islamic_Eras },
             { "calendarname.buddhist", "\u0e1b\u0e0f\u0e34\u0e17\u0e34\u0e19\u0e1e\u0e38\u0e17\u0e18" },
             { "standalone.MonthNames", metaValue_MonthNames },
+            { "latn.NumberPatterns",
+                new String[] {
+                    "#,##0.###",
+                    "\u00a4#,##0.00",
+                    "#,##0%",
+                    "\u00a4#,##0.00;(\u00a4#,##0.00)",
+                }
+            },
             { "buddhist.DayNarrows", metaValue_DayNarrows },
             { "java.time.islamic.long.Eras", metaValue_java_time_islamic_long_Eras },
             { "japanese.DayNarrows", metaValue_DayNarrows },
