@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2019, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -70,21 +66,19 @@ import sun.util.resources.OpenListResourceBundle;
 public class LocaleNames_eu extends OpenListResourceBundle {
     @Override
     protected final Object[][] getContents() {
-        final String metaValue_gu = "gujaratera";
-        final String metaValue_he = "hebreera";
-        final String metaValue_la = "latina";
         final String metaValue_si = "sinhala";
         final Object[][] data = new Object[][] {
             { "ksh", "koloniera" },
             { "mwl", "mirandera" },
             { "Zsym", "ikurrak" },
             { "Zsye", "emotikonoa" },
+            { "ccp", "chakmera" },
             { "tem", "temnea" },
             { "teo", "tesoera" },
             { "rap", "rapa nui" },
             { "AC", "Ascension uhartea" },
             { "rar", "rarotongera" },
-            { "tet", "tetuma" },
+            { "tet", "tetum" },
             { "AD", "Andorra" },
             { "AE", "Arabiar Emirerri Batuak" },
             { "nl_BE", "flandriera" },
@@ -102,8 +96,8 @@ public class LocaleNames_eu extends OpenListResourceBundle {
             { "AT", "Austria" },
             { "AU", "Australia" },
             { "AW", "Aruba" },
-            { "en_US", "AEBko ingelesa" },
-            { "AX", "Aland uharteak" },
+            { "en_US", "AEBko ingeles" },
+            { "AX", "\u00c5land" },
             { "AZ", "Azerbaijan" },
             { "BA", "Bosnia-Herzegovina" },
             { "BB", "Barbados" },
@@ -133,7 +127,7 @@ public class LocaleNames_eu extends OpenListResourceBundle {
             { "type.ca.persian", "Egutegi persiarra" },
             { "type.nu.hebr", "Zenbaki hebrearrak" },
             { "CA", "Kanada" },
-            { "CC", "Cocos uharteak" },
+            { "CC", "Cocos (Keeling) uharteak" },
             { "mzn", "mazandarandera" },
             { "CD", "Kongoko Errepublika Demokratikoa" },
             { "CF", "Afrika Erdiko Errepublika" },
@@ -175,7 +169,7 @@ public class LocaleNames_eu extends OpenListResourceBundle {
             { "EA", "Ceuta eta Melilla" },
             { "pam", "pampangera" },
             { "EC", "Ekuador" },
-            { "pap", "papiamentoa" },
+            { "pap", "papiamento" },
             { "ada", "adangmera" },
             { "EE", "Estonia" },
             { "EG", "Egipto" },
@@ -196,7 +190,7 @@ public class LocaleNames_eu extends OpenListResourceBundle {
             { "ady", "adigera" },
             { "FI", "Finlandia" },
             { "FJ", "Fiji" },
-            { "FK", "Malvinak" },
+            { "FK", "Falklandak" },
             { "FM", "Mikronesia" },
             { "key.va", "Eskualdeko ezarpenen aldaera" },
             { "FO", "Faroe uharteak" },
@@ -225,15 +219,15 @@ public class LocaleNames_eu extends OpenListResourceBundle {
             { "GW", "Ginea Bissau" },
             { "tlh", "klingonera" },
             { "GY", "Guyana" },
-            { "ckb", "sorania" },
+            { "ckb", "erdialdeko kurduera" },
             { "zxx", "ez dago eduki linguistikorik" },
-            { "de_AT", "Austriako alemana" },
+            { "de_AT", "Austriako aleman" },
             { "HK", "Hong Kong Txinako AEB" },
             { "HM", "Heard eta McDonald uharteak" },
             { "HN", "Honduras" },
             { "HR", "Kroazia" },
             { "agq", "aghemera" },
-            { "gsw", "alemana (Suitza)" },
+            { "gsw", "Suitzako aleman" },
             { "HT", "Haiti" },
             { "HU", "Hungaria" },
             { "IC", "Kanariak" },
@@ -241,7 +235,7 @@ public class LocaleNames_eu extends OpenListResourceBundle {
             { "IE", "Irlanda" },
             { "nap", "napoliera" },
             { "naq", "namera" },
-            { "zza", "zazakia" },
+            { "zza", "zazera" },
             { "IL", "Israel" },
             { "IM", "Man uhartea" },
             { "IN", "India" },
@@ -252,17 +246,17 @@ public class LocaleNames_eu extends OpenListResourceBundle {
             { "IT", "Italia" },
             { "Zmth", "matematikako notazioa" },
             { "type.nu.thai", "Digitu thailandiarrak" },
-            { "type.nu.beng", "digitu bengalarrak" },
+            { "type.nu.beng", "Digitu bengalarrak" },
             { "JE", "Jersey" },
             { "type.ca.islamic", "Islamiar egutegia" },
             { "JM", "Jamaika" },
-            { "Beng", "bengaliarra" },
+            { "Beng", "bengalarra" },
             { "JO", "Jordania" },
             { "JP", "Japonia" },
             { "ain", "ainuera" },
             { "guz", "gusiiera" },
             { "type.nu.knda", "Digitu kannadarrak" },
-            { "de_CH", "aleman garaia (Suitza)" },
+            { "de_CH", "Suitzako aleman garai" },
             { "type.co.phonetic", "Ordenatzeko irizpide fonetikoa" },
             { "type.ca.buddhist", "Egutegi budista" },
             { "KE", "Kenya" },
@@ -273,12 +267,12 @@ public class LocaleNames_eu extends OpenListResourceBundle {
             { "KM", "Komoreak" },
             { "KN", "Saint Kitts eta Nevis" },
             { "Knda", "kanadarra" },
-            { "fr_CA", "Kanadako frantsesa" },
+            { "fr_CA", "Kanadako frantses" },
             { "KP", "Ipar Korea" },
             { "KR", "Hego Korea" },
-            { "fr_CH", "Suitzako frantsesa" },
+            { "fr_CH", "Suitzako frantses" },
             { "KW", "Kuwait" },
-            { "tpi", "tok pisina" },
+            { "tpi", "tok pisin" },
             { "KY", "Kaiman uharteak" },
             { "KZ", "Kazakhstan" },
             { "Cyrl", "zirilikoa" },
@@ -286,6 +280,7 @@ public class LocaleNames_eu extends OpenListResourceBundle {
             { "LB", "Libano" },
             { "LC", "Santa Luzia" },
             { "gwi", "gwich\u02bcin" },
+            { "nds", "behe-aleman" },
             { "LI", "Liechtenstein" },
             { "LK", "Sri Lanka" },
             { "LR", "Liberia" },
@@ -295,8 +290,8 @@ public class LocaleNames_eu extends OpenListResourceBundle {
             { "LV", "Letonia" },
             { "Kana", "katakana" },
             { "LY", "Libia" },
-            { "lad", "ladinera" },
-            { "vun", "vunjoa" },
+            { "lad", "ladino" },
+            { "vun", "vunjo" },
             { "lag", "langiera" },
             { "Thaa", "thaana" },
             { "MA", "Maroko" },
@@ -309,7 +304,7 @@ public class LocaleNames_eu extends OpenListResourceBundle {
             { "ale", "aleutera" },
             { "Thai", "thailandiarra" },
             { "type.nu.vaii", "Vai digituak" },
-            { "MK", "Mazedonia" },
+            { "MK", "Ipar Mazedonia" },
             { "ML", "Mali" },
             { "MM", "Myanmar (Birmania)" },
             { "MN", "Mongolia" },
@@ -320,7 +315,7 @@ public class LocaleNames_eu extends OpenListResourceBundle {
             { "MR", "Mauritania" },
             { "MS", "Montserrat" },
             { "MT", "Malta" },
-            { "type.m0.ungegn", "UNGEGN bihurketa" },
+            { "type.m0.ungegn", "UN GEGN transliterazioa" },
             { "MU", "Maurizio" },
             { "alt", "hegoaldeko altaiera" },
             { "MV", "Maldivak" },
@@ -344,14 +339,14 @@ public class LocaleNames_eu extends OpenListResourceBundle {
             { "NP", "Nepal" },
             { "NR", "Nauru" },
             { "NU", "Niue" },
-            { "rof", "romboera" },
+            { "rof", "rombo" },
             { "NZ", "Zeelanda Berria" },
             { "OM", "Oman" },
             { "anp", "angikera" },
-            { "crs", "seselwa frantses-kreolera" },
+            { "crs", "Seychelleetako kreolera" },
             { "PA", "Panama" },
             { "type.ca.islamic-civil", "Islamiar egutegi zibila" },
-            { "en_GB", "Britainia Handiko ingelesa" },
+            { "en_GB", "Britania Handiko ingeles" },
             { "PE", "Peru" },
             { "PF", "Polinesia Frantsesa" },
             { "PG", "Papua Ginea Berria" },
@@ -362,17 +357,17 @@ public class LocaleNames_eu extends OpenListResourceBundle {
             { "PM", "Saint-Pierre eta Mikelune" },
             { "PN", "Pitcairn uharteak" },
             { "PR", "Puerto Rico" },
-            { "PS", "Palestinako Lurraldeak" },
+            { "PS", "Palestinar Lurralde Okupatuak" },
             { "PT", "Portugal" },
             { "PW", "Palau" },
-            { "nia", "niasa" },
+            { "nia", "niasera" },
             { "type.nu.greklow", "Zenbaki grekoak minuskulaz" },
             { "PY", "Paraguai" },
             { "tum", "tumbukera" },
-            { "Hebr", metaValue_he },
+            { "Hebr", "hebrearra" },
             { "QA", "Qatar" },
             { "%%SCOTLAND", "ESKOZIAR INGELESA" },
-            { "niu", "niuera" },
+            { "niu", "niueera" },
             { "QO", "Mugaz kanpoko Ozeania" },
             { "lez", "lezgiera" },
             { "tvl", "tuvaluera" },
@@ -389,7 +384,7 @@ public class LocaleNames_eu extends OpenListResourceBundle {
             { "RW", "Ruanda" },
             { "SA", "Saudi Arabia" },
             { "SB", "Salomon Uharteak" },
-            { "twq", "tasawaqa" },
+            { "twq", "tasawaq" },
             { "011", "Afrika mendebaldea" },
             { "SC", "Seychelleak" },
             { "SD", "Sudan" },
@@ -410,8 +405,8 @@ public class LocaleNames_eu extends OpenListResourceBundle {
             { "SM", "San Marino" },
             { "SN", "Senegal" },
             { "SO", "Somalia" },
-            { "arn", "maputxea" },
-            { "arp", "arapahoa" },
+            { "arn", "maputxe" },
+            { "arp", "arapaho" },
             { "type.nu.taml", "Zenbaki tamilar tradizionalak" },
             { "SR", "Surinam" },
             { "SS", "Hego Sudan" },
@@ -421,11 +416,11 @@ public class LocaleNames_eu extends OpenListResourceBundle {
             { "SY", "Siria" },
             { "SZ", "Swazilandia" },
             { "TA", "Tristan da Cunha" },
-            { "asa", "asua" },
+            { "asa", "asu" },
             { "type.ms.ussystem", "Neurketa-sistema anglosaxoia" },
-            { "021", "Amerika iparraldea" },
+            { "021", "Amerikako iparraldea" },
             { "TC", "Turk eta Caico uharteak" },
-            { "yav", "jangbenera" },
+            { "yav", "yangbenera" },
             { "TD", "Txad" },
             { "TF", "Hegoaldeko lurralde frantsesak" },
             { "TG", "Togo" },
@@ -448,12 +443,12 @@ public class LocaleNames_eu extends OpenListResourceBundle {
             { "nmg", "kwasiera" },
             { "Zzzz", "idazkera ezezaguna" },
             { "UA", "Ukraina" },
-            { "rup", "aromania" },
+            { "rup", "aromaniera" },
             { "030", "Asia ekialdea" },
             { "tyv", "tuvera" },
             { "sw_CD", "Kongoko swahilia" },
             { "034", "Asia hegoaldea" },
-            { "035", "Asia hego-ekialdea" },
+            { "035", "Asiako hego-ekialdea" },
             { "UG", "Uganda" },
             { "type.co.pinyin", "Pinyin hurrenkera" },
             { "039", "Europa hegoaldea" },
@@ -477,7 +472,7 @@ public class LocaleNames_eu extends OpenListResourceBundle {
             { "VN", "Vietnam" },
             { "VU", "Vanuatu" },
             { "nog", "nogaiera" },
-            { "rwk", "rwaera" },
+            { "rwk", "rwera" },
             { "053", "Australasia" },
             { "054", "Melanesia" },
             { "WF", "Wallis eta Futuna" },
@@ -489,11 +484,13 @@ public class LocaleNames_eu extends OpenListResourceBundle {
             { "wae", "walserera" },
             { "WS", "Samoa" },
             { "wal", "welayta" },
+            { "XA", "Sasiazentuak" },
             { "war", "samerera" },
+            { "XB", "Pseudobidia" },
             { "awa", "awadhiera" },
             { "061", "Polinesia" },
             { "XK", "Kosovo" },
-            { "Gujr", metaValue_gu },
+            { "Gujr", "gujaratarra" },
             { "Zxxx", "idatzi gabea" },
             { "YE", "Yemen" },
             { "nqo", "n\u2019koera" },
@@ -512,9 +509,9 @@ public class LocaleNames_eu extends OpenListResourceBundle {
             { "nso", "pediera" },
             { "type.nu.telu", "Digitu teluguarrak" },
             { "loz", "loziera" },
-            { "jmc", "machamera" },
+            { "jmc", "machame" },
             { "type.nu.hansfin", "Finantzetarako zenbaki txinatar sinplifikatuak" },
-            { "hil", "hiligainona" },
+            { "hil", "hiligainon" },
             { "type.nu.arabext", "Digitu arabiar-hindiko hedatuak" },
             { "nus", "nuerera" },
             { "dak", "dakotera" },
@@ -524,7 +521,7 @@ public class LocaleNames_eu extends OpenListResourceBundle {
             { "lrc", "iparraldeko lurera" },
             { "udm", "udmurtera" },
             { "Khmr", "khemerarra" },
-            { "sad", "sandawea" },
+            { "sad", "sandaweera" },
             { "type.nu.roman", "Zenbaki erromatarrak" },
             { "sah", "sakhera" },
             { "saq", "samburuera" },
@@ -550,19 +547,19 @@ public class LocaleNames_eu extends OpenListResourceBundle {
             { "scn", "siziliera" },
             { "aa", "afarera" },
             { "ab", "abkhaziera" },
-            { "af", "afrikaansa" },
+            { "af", "afrikaans" },
             { "ak", "akanera" },
             { "am", "amharera" },
             { "an", "aragoiera" },
             { "Arab", "arabiarra" },
             { "Jpan", "japoniarra" },
             { "ar", "arabiera" },
-            { "Hrkt", "silaba japoniarrak" },
+            { "Hrkt", "silabario japoniarrak" },
             { "as", "assamera" },
             { "av", "avarera" },
             { "ay", "aimara" },
             { "az", "azerbaijanera" },
-            { "ba", "bashkirrera" },
+            { "ba", "baxkirera" },
             { "type.co.unihan", "Radical trazuen hurrenkera" },
             { "be", "bielorrusiera" },
             { "bg", "bulgariera" },
@@ -576,21 +573,21 @@ public class LocaleNames_eu extends OpenListResourceBundle {
             { "Mymr", "birmaniarra" },
             { "type.nu.laoo", "Digitu laostarrak" },
             { "seh", "senera" },
-            { "ca", "katalana" },
-            { "ses", "koyraboro sennia" },
-            { "ce", "txetxeniera" },
+            { "ca", "katalan" },
+            { "ses", "koyraboro senni" },
+            { "ce", "txetxenera" },
             { "ch", "chamorrera" },
             { "%%REVISED", "BERRIKUSIA" },
             { "co", "korsikera" },
             { "Orya", "oriyarra" },
             { "cs", "txekiera" },
-            { "cu", "Elizako eslaviera" },
-            { "cv", "chuvashera" },
-            { "cy", "galesa" },
+            { "cu", "elizako eslaviera" },
+            { "cv", "txuvaxera" },
+            { "cy", "gales" },
             { "type.nu.ethi", "Zenbaki etiopiarrak" },
             { "da", "daniera" },
-            { "pt_PT", "portugesa (Europa)" },
-            { "de", "alemana" },
+            { "pt_PT", "Europako portuges" },
+            { "de", "aleman" },
             { "type.cf.standard", "Moneta-formatu estandarra" },
             { "bem", "bembera" },
             { "type.nu.mong", "Digitu mongoliarrak" },
@@ -605,15 +602,15 @@ public class LocaleNames_eu extends OpenListResourceBundle {
             { "type.lb.normal", "Lerro-jauziaren estilo arrunta" },
             { "ro_MD", "moldaviera" },
             { "el", "greziera" },
-            { "en", "ingelesa" },
-            { "eo", "esperantoa" },
+            { "en", "ingeles" },
+            { "eo", "esperanto" },
             { "type.co.big5han", "Txinera tradizionalaren alfabetoa-Big5" },
             { "es", "espainiera" },
             { "et", "estoniera" },
             { "Hanb", "h\u00e4nera" },
             { "eu", "euskara" },
             { "Hang", "hangula" },
-            { "shi", "tachelhita" },
+            { "shi", "tachelhit" },
             { "hsb", "goi-sorabiera" },
             { "Hani", "idazkera txinatarra" },
             { "shn", "shanera" },
@@ -627,29 +624,29 @@ public class LocaleNames_eu extends OpenListResourceBundle {
             { "fon", "fona" },
             { "yue", "kantonera" },
             { "fo", "faroera" },
-            { "type.m0.bgn", "BGN bihurketa" },
-            { "umb", "umbunduera" },
-            { "fr", "frantsesa" },
+            { "type.m0.bgn", "US BGN transliterazioa" },
+            { "umb", "umbundu" },
+            { "fr", "frantses" },
             { "fy", "frisiera" },
-            { "ga", "gaelikoa" },
-            { "gd", "Eskoziako gaelikoa" },
+            { "ga", "irlandera" },
+            { "gd", "Eskoziako gaeliko" },
             { "gl", "galiziera" },
             { "gn", "guaraniera" },
             { "bho", "bhojpurera" },
             { "und", "hizkuntza ezezaguna" },
             { "type.ca.ethiopic-amete-alem", "Amete Alem egutegi etiopiarra" },
-            { "gu", metaValue_gu },
+            { "gu", "gujaratera" },
             { "gv", "manxera" },
             { "ha", "hausa" },
-            { "he", metaValue_he },
-            { "hi", "hindia" },
+            { "he", "hebreera" },
+            { "hi", "hindi" },
             { "hup", "hupera" },
             { "bin", "edoera" },
             { "hr", "kroaziera" },
             { "ht", "Haitiko kreolera" },
             { "hu", "hungariera" },
             { "hy", "armeniera" },
-            { "hz", "herera" },
+            { "hz", "hereroera" },
             { "ia", "interlingua" },
             { "Jamo", "jamo-bihurketa" },
             { "id", "indonesiera" },
@@ -660,16 +657,16 @@ public class LocaleNames_eu extends OpenListResourceBundle {
             { "io", "ido" },
             { "is", "islandiera" },
             { "it", "italiera" },
-            { "iu", "inuitera" },
+            { "iu", "inuktitut" },
             { "ja", "japoniera" },
-            { "Mlym", "malayalamera" },
+            { "Mlym", "malayalamarra" },
             { "sma", "hegoaldeko samiera" },
             { "jv", "javera" },
             { "mad", "madurera" },
-            { "smj", "lule samiera" },
+            { "smj", "Luleko samiera" },
             { "mag", "magahiera" },
             { "mai", "maithilera" },
-            { "smn", "inari-samiera" },
+            { "smn", "Inariko samiera" },
             { "ka", "georgiera" },
             { "bla", "siksikera" },
             { "mak", "makasarera" },
@@ -690,7 +687,7 @@ public class LocaleNames_eu extends OpenListResourceBundle {
             { "kw", "kornubiera" },
             { "ky", "kirgizera" },
             { "snk", "soninkera" },
-            { "la", metaValue_la },
+            { "la", "latin" },
             { "lb", "luxenburgera" },
             { "type.nu.mlym", "Digitu malayalamarrak" },
             { "lg", "gandera" },
@@ -701,9 +698,9 @@ public class LocaleNames_eu extends OpenListResourceBundle {
             { "lo", "laosera" },
             { "type.ms.uksystem", "Neurketa-sistema inperiala" },
             { "lt", "lituaniera" },
-            { "lu", "luba-katangera" },
+            { "lu", "Katangako lubera" },
             { "lv", "letoniera" },
-            { "mg", "malgaxea" },
+            { "mg", "malgaxe" },
             { "mh", "marshallera" },
             { "type.co.ducet", "Unicode hurrenkera lehenetsia" },
             { "mi", "maoriera" },
@@ -719,15 +716,15 @@ public class LocaleNames_eu extends OpenListResourceBundle {
             { "dsb", "behe-sorabiera" },
             { "na", "nauruera" },
             { "type.co.search", "Bilaketa orokorra" },
-            { "nb", "bokmala (Norvegia)" },
+            { "nb", "bokm\u00e5l (norvegiera)" },
             { "nd", "iparraldeko ndebeleera" },
             { "ne", "nepalera" },
             { "ng", "ndongera" },
             { "nl", "nederlandera" },
-            { "nn", "nynorsk norvegiera" },
+            { "nn", "nynorsk (norvegiera)" },
             { "no", "norvegiera" },
             { "nr", "hegoaldeko ndebelera" },
-            { "nv", "navahoera" },
+            { "nv", "navajoera" },
             { "ny", "chewera" },
             { "kac", "jingpoera" },
             { "kab", "kabilera" },
@@ -749,22 +746,22 @@ public class LocaleNames_eu extends OpenListResourceBundle {
             { "pl", "poloniera" },
             { "type.ca.dangi", "Dangi egutegia" },
             { "ps", "paxtuera" },
-            { "pt", "portugesa" },
+            { "pt", "portuges" },
             { "key.co", "Ordenatzeko irizpidea" },
-            { "pt_BR", "Brasilgo portugesa" },
+            { "pt_BR", "Brasilgo portuges" },
             { "kcg", "kataba" },
             { "mgh", "makhuwa-meettoera" },
             { "key.cf", "Moneta-formatua" },
             { "key.ca", "Egutegia" },
             { "Laoo", "laosarra" },
-            { "mgo", "metera" },
+            { "mgo", "meta\u02bcera" },
             { "type.hc.h23", "24 orduko sistema (0\u201323)" },
             { "type.hc.h24", "24 orduko sistema (1\u201324)" },
             { "ssy", "sahoa" },
             { "type.nu.mymr", "Digitu birmaniarrak" },
             { "qu", "kitxua" },
             { "brx", "bodoera" },
-            { "kde", "makondera" },
+            { "kde", "makondeera" },
             { "Ethi", "etiopiarra" },
             { "type.hc.h12", "12 orduko sistema (1\u201312)" },
             { "type.hc.h11", "12 orduko sistema (0\u201311)" },
@@ -777,16 +774,16 @@ public class LocaleNames_eu extends OpenListResourceBundle {
             { "type.nu.hanidec", "Zenbaki hamartar txinatarrak" },
             { "ru", "errusiera" },
             { "rw", "kinyaruanda" },
-            { "kea", "Cabo Verdeko kreola" },
+            { "kea", "Cabo Verdeko kreolera" },
             { "mic", "mikmakera" },
             { "suk", "sukumera" },
-            { "en_AU", "Australiako ingelesa" },
-            { "sa", "sanskritoa" },
+            { "en_AU", "Australiako ingeles" },
+            { "sa", "sanskrito" },
             { "sc", "sardiniera" },
-            { "sd", "sindhia" },
+            { "sd", "sindhi" },
             { "se", "iparraldeko samiera" },
             { "min", "minangkabauera" },
-            { "sg", "sangoa" },
+            { "sg", "sango" },
             { "sh", "serbokroaziera" },
             { "si", metaValue_si },
             { "sk", "eslovakiera" },
@@ -809,14 +806,14 @@ public class LocaleNames_eu extends OpenListResourceBundle {
             { "ta", "tamilera" },
             { "142", "Asia" },
             { "143", "Asia erdialdea" },
-            { "te", "telugua" },
+            { "te", "telugu" },
             { "145", "Asia mendebaldea" },
             { "tg", "tajikera" },
             { "th", "thailandiera" },
-            { "ti", "tigri\u00f1era" },
+            { "ti", "tigrinyera" },
             { "bug", "buginera" },
             { "kfo", "koroa" },
-            { "en_CA", "Kanadako ingelesa" },
+            { "en_CA", "Kanadako ingeles" },
             { "tk", "turkmenera" },
             { "tl", "tagalog" },
             { "tn", "tswanera" },
@@ -839,7 +836,7 @@ public class LocaleNames_eu extends OpenListResourceBundle {
             { "Zyyy", "ohikoa" },
             { "uk", "ukrainera" },
             { "type.ca.coptic", "Egutegi coptiarra" },
-            { "ur", "urdua" },
+            { "ur", "urdu" },
             { "xal", "kalmykera" },
             { "uz", "uzbekera" },
             { "kha", "kashia" },
@@ -847,29 +844,29 @@ public class LocaleNames_eu extends OpenListResourceBundle {
             { "ve", "vendera" },
             { "type.ca.roc", "Minguo egutegia" },
             { "vi", "vietnamera" },
-            { "khq", "koyra chiiniera" },
+            { "khq", "koyra chiini" },
             { "key.hc", "Ordu-zikloa (12 vs 24)" },
-            { "vo", "volap\u00fcka" },
+            { "vo", "volap\u00fck" },
             { "quc", "quicheera" },
             { "gaa", "ga" },
             { "wa", "waloiera" },
             { "gag", "gagauzera" },
             { "syr", "asiriera" },
-            { "Grek", "greziarra" },
+            { "Grek", "grekoa" },
             { "wo", "wolofera" },
             { "zgh", "amazigera estandarra" },
             { "ar_001", "arabiera moderno estandarra" },
             { "Mong", "mongoliarra" },
             { "mni", "manipurera" },
-            { "Latn", metaValue_la },
+            { "Latn", "latinoa" },
             { "type.nu.hans", "Zenbaki txinatar sinplifikatuak" },
             { "type.nu.hant", "Zenbaki txinatar tradizionalak" },
             { "xh", "xhosera" },
             { "type.nu.romanlow", "Zenbaki erromatarrak minuskulaz" },
             { "byn", "bilena" },
             { "moh", "mohawkera" },
-            { "kkj", "kakoa" },
-            { "yi", "yiddisha" },
+            { "kkj", "kako" },
+            { "yi", "yiddish" },
             { "mos", "moreera" },
             { "yo", "jorubera" },
             { "type.nu.traditional", "Zenbaki tradizionalak" },
@@ -887,12 +884,12 @@ public class LocaleNames_eu extends OpenListResourceBundle {
             { "gez", "ge\u2019ez" },
             { "type.co.reformed", "Erreformaren araberako hurrenkera" },
             { "ebu", "embua" },
-            { "zh_Hans", "txinera soildua" },
+            { "zh_Hans", "txinera sinplifikatu" },
             { "koi", "komi-permyakera" },
             { "kok", "konkanera" },
             { "zh_Hant", "txinera tradizionala" },
             { "kpe", "kpellea" },
-            { "type.nu.khmr", "Digitu khmerarrak" },
+            { "type.nu.khmr", "Digitu khemerarrak" },
             { "ilo", "ilokanera" },
             { "%%VALENCIA", "VALENTZIERA" },
             { "mua", "mudangera" },
@@ -904,6 +901,7 @@ public class LocaleNames_eu extends OpenListResourceBundle {
             { "type.nu.tamldec", "Digitu tamilarrak" },
             { "krc", "karachayera-balkarera" },
             { "inh", "ingushera" },
+            { "fa_AF", "daria" },
             { "krl", "kareliera" },
             { "efi", "efikera" },
             { "key.nu", "Zenbakiak" },
