@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -121,7 +117,6 @@ public class LocaleNames_ms extends OpenListResourceBundle {
         final String metaValue_WS = "Samoa";
         final String metaValue_ae = "Avestan";
         final String metaValue_ar = "Arab";
-        final String metaValue_bn = "Benggala";
         final String metaValue_bo = "Tibet";
         final String metaValue_el = "Greek";
         final String metaValue_he = "Ibrani";
@@ -144,6 +139,7 @@ public class LocaleNames_ms extends OpenListResourceBundle {
         final String metaValue_mak = "Makasar";
         final String metaValue_men = "Mende";
         final String metaValue_nqo = "N\u2019ko";
+        final String metaValue_ssy = "Saho";
         final String metaValue_vai = "Vai";
         final Object[][] data = new Object[][] {
             { "ksh", "Colognian" },
@@ -153,6 +149,7 @@ public class LocaleNames_ms extends OpenListResourceBundle {
             { "type.nu.lanatham", "Digit Tai Tham Tham" },
             { "Tagb", "Tagbanwa" },
             { "Zsye", "Emoji" },
+            { "%%NJIVA", "Dialek Gniva/Njiva" },
             { "ccp", metaValue_ccp },
             { "Phag", "Phags-pa" },
             { "tem", "Timne" },
@@ -163,6 +160,7 @@ public class LocaleNames_ms extends OpenListResourceBundle {
             { "AC", "Pulau Ascension" },
             { "rar", "Rarotonga" },
             { "tet", "Tetum" },
+            { "%%BARLA", "Kumpulan dialek Barlavento Kabuverdianu" },
             { "type.nu.sinh", "Digit Sinhala Lith" },
             { "AD", "Andorra" },
             { "AE", "Emiriah Arab Bersatu" },
@@ -241,6 +239,7 @@ public class LocaleNames_ms extends OpenListResourceBundle {
             { "CZ", "Czechia" },
             { "eka", "Ekajuk" },
             { "Pauc", "Pau Cin Hau" },
+            { "%%RIGIK", "Vopaluk Klasik" },
             { "Sogd", "Sogdia" },
             { "DE", metaValue_DE },
             { "ace", "Aceh" },
@@ -296,6 +295,7 @@ public class LocaleNames_ms extends OpenListResourceBundle {
             { "Taml", metaValue_ta },
             { "FR", metaValue_FR },
             { "root", "Root" },
+            { "%%DAJNKO", "Abjad Dajnko" },
             { "type.ca.indian", "Kalendar Kebangsaan India" },
             { "grc", "Greek Purba" },
             { "GA", "Gabon" },
@@ -343,6 +343,7 @@ public class LocaleNames_ms extends OpenListResourceBundle {
             { "type.nu.kali", "Digit Kayah Li" },
             { "IE", metaValue_IE },
             { "nap", "Neapolitan" },
+            { "%%NDYUKA", "Dialek Ndyuka" },
             { "naq", "Nama" },
             { "type.nu.sora", "Digit Sora Sompeng" },
             { "zza", "Zaza" },
@@ -364,10 +365,12 @@ public class LocaleNames_ms extends OpenListResourceBundle {
             { "type.nu.cyrl", "Digit Cyril" },
             { "JE", "Jersey" },
             { "type.ca.islamic", "Kalendar Islam" },
-            { "Beng", metaValue_bn },
             { "JM", "Jamaica" },
+            { "Beng", "Benggala" },
+            { "%%EKAVSK", "Serbia dengan sebutan Ekavia" },
             { "JO", "Jordan" },
             { "JP", metaValue_JP },
+            { "%%1606NICT", "Lewat Pertengahan Era Perancis hingga 1606" },
             { "ain", "Ainu" },
             { "Mend", metaValue_men },
             { "guz", "Gusii" },
@@ -457,6 +460,8 @@ public class LocaleNames_ms extends OpenListResourceBundle {
             { "type.ca.hebrew", "Kalendar Ibrani" },
             { "type.co.dictionary", "Aturan Isih Kamus" },
             { "NC", "New Caledonia" },
+            { "%%WADEGILE", "Perumian Wade-Giles" },
+            { "%%UCRCOR", "Sistem Ejaan Semakan Bersatu" },
             { "NE", "Niger" },
             { "NF", "Pulau Norfolk" },
             { "NG", "Nigeria" },
@@ -473,6 +478,7 @@ public class LocaleNames_ms extends OpenListResourceBundle {
             { "rof", "Rombo" },
             { "NZ", "New Zealand" },
             { "Merc", "Kursif Meroitic" },
+            { "%%COLB1945", "Konvensyen Sistem Ejaan Portugis-Brazil 1945" },
             { "Mero", "Meroitic" },
             { "crh", "Turki Krimea" },
             { "OM", "Oman" },
@@ -509,9 +515,11 @@ public class LocaleNames_ms extends OpenListResourceBundle {
             { "QO", "Oceania Terpencil" },
             { "lez", "Lezghian" },
             { "type.nu.ahom", "Digit Ahom" },
+            { "%%FONUPA", "Fonetik UPA" },
             { "type.nu.takr", "Digit Takri" },
             { "tvl", metaValue_TV },
             { "Tavt", "Tai Viet" },
+            { "%%SOTAV", "Kumpulan dialek Sotavento Kabuverdianu" },
             { "Maka", metaValue_mak },
             { "001", "Dunia" },
             { "002", "Afrika" },
@@ -528,6 +536,7 @@ public class LocaleNames_ms extends OpenListResourceBundle {
             { "RU", metaValue_RU },
             { "RW", "Rwanda" },
             { "type.nu.talu", "Digit Tai Lue Baru" },
+            { "%%METELKO", "Abjad Metelko" },
             { "Mani", "Manichaean" },
             { "Ugar", "Ugaritic" },
             { "Khar", "Kharoshthi" },
@@ -552,7 +561,6 @@ public class LocaleNames_ms extends OpenListResourceBundle {
             { "SJ", "Svalbard dan Jan Mayen" },
             { "019", "Amerika" },
             { "SK", "Slovakia" },
-            { "Bamu", "Bamu" },
             { "SL", "Sierra Leone" },
             { "SM", "San Marino" },
             { "SN", "Senegal" },
@@ -589,8 +597,10 @@ public class LocaleNames_ms extends OpenListResourceBundle {
             { "ybb", "Yemba" },
             { "type.co.searchjl", "Cari Mengikut Konsonan Awal Hangul" },
             { "TM", "Turkmenistan" },
+            { "%%BOONT", "Boontling" },
             { "TN", "Tunisia" },
             { "TO", metaValue_TO },
+            { "%%NULIK", "Volapuk Moden" },
             { "TR", metaValue_TR },
             { "TT", "Trinidad dan Tobago" },
             { "TV", metaValue_TV },
@@ -617,6 +627,7 @@ public class LocaleNames_ms extends OpenListResourceBundle {
             { "UN", "Bangsa-bangsa Bersatu" },
             { "US", "Amerika Syarikat" },
             { "haw", "Hawaii" },
+            { "%%1959ACAD", "Akademik" },
             { "type.co.gb2312han", "Aturan Isih Bahasa Cina Ringkas - GB2312" },
             { "UY", "Uruguay" },
             { "prg", "Prusia" },
@@ -643,15 +654,19 @@ public class LocaleNames_ms extends OpenListResourceBundle {
             { "jgo", "Ngomba" },
             { "lkt", "Lakota" },
             { "type.nu.finance", "Angka Kewangan" },
+            { "%%HEPBURN", "Perumian Hepburn" },
             { "type.co.compat", "Tertib Isihan Sebelumnya" },
             { "wae", "Walser" },
             { "WS", metaValue_WS },
             { "Bass", "Bassa Vah" },
             { "type.nu.mtei", "Digit Meetei Mayek" },
             { "wal", "Wolaytta" },
+            { "XA", "Aksen Pseudo" },
             { "war", "Waray" },
+            { "XB", "Bidi Pseudo" },
             { "awa", "Awadhi" },
             { "061", "Polinesia" },
+            { "%%KSCOR", "Sistem Ejaan Standard" },
             { "XK", "Kosovo" },
             { "type.nu.brah", "Digit Brahmi" },
             { "Gujr", "Gujarat" },
@@ -663,6 +678,8 @@ public class LocaleNames_ms extends OpenListResourceBundle {
             { "nqo", metaValue_nqo },
             { "type.co.standard", "Tertib Isih Standard" },
             { "Zanb", "Segi Empat Zanabazar" },
+            { "%%BALANKA", "Dialek Balanka Anii" },
+            { "%%ROZAJ", "Resia" },
             { "Sgnw", "Tulisan Isyarat" },
             { "YT", "Mayotte" },
             { "type.nu.cham", "Digit Cham" },
@@ -674,6 +691,7 @@ public class LocaleNames_ms extends OpenListResourceBundle {
             { "type.co.zhuyin", "Aturan Isih Zhuyin" },
             { "Hira", "Hiragana" },
             { "ZM", "Zambia" },
+            { "%%PINYIN", "Perumian Pinyin" },
             { "ZW", "Zimbabwe" },
             { "ZZ", "Wilayah Tidak Diketahui" },
             { "Runr", "Runic" },
@@ -711,6 +729,7 @@ public class LocaleNames_ms extends OpenListResourceBundle {
             { "type.nu.native", "Digit Asal" },
             { "sba", "Ngambay" },
             { "Guru", "Gurmukhi" },
+            { "%%ALUKU", "Dialek Aluku" },
             { "lua", "Luba-Lulua" },
             { "type.nu.tirh", "Digit Tirhuta" },
             { "type.d0.fwidth", "Ke Kelebaran Penuh" },
@@ -727,11 +746,13 @@ public class LocaleNames_ms extends OpenListResourceBundle {
             { "luy", "Luyia" },
             { "bas", "Basaa" },
             { "bax", "Bamun" },
+            { "%%ABL1943", "Perumusan sistem ejaan 1943" },
             { "es_ES", "Sepanyol Eropah" },
             { "sco", "Scots" },
             { "scn", "Sicili" },
             { "aa", "Afar" },
             { "ab", "Abkhazia" },
+            { "Aran", "Nastaliq" },
             { "ae", metaValue_ae },
             { "af", "Afrikaans" },
             { "ak", "Akan" },
@@ -740,6 +761,7 @@ public class LocaleNames_ms extends OpenListResourceBundle {
             { "am", "Amharic" },
             { "Arab", metaValue_ar },
             { "an", "Aragon" },
+            { "%%SOLBA", "Dialek Stolvizza/Solbica" },
             { "Jpan", metaValue_JP },
             { "ar", metaValue_ar },
             { "Hrkt", "Ejaan sukuan Jepun" },
@@ -752,6 +774,8 @@ public class LocaleNames_ms extends OpenListResourceBundle {
             { "az", metaValue_AZ },
             { "Rohg", "Hanifi Rohingya" },
             { "Khoj", "Khojki" },
+            { "%%OSOJS", "Dialek Oseacco/Osojane" },
+            { "%%UNIFON", "Abjad fonetik Unifon" },
             { "ba", "Bashkir" },
             { "type.co.unihan", "Aturan Isih Coretan Radikal" },
             { "be", metaValue_BY },
@@ -759,7 +783,7 @@ public class LocaleNames_ms extends OpenListResourceBundle {
             { "bi", "Bislama" },
             { "type.nu.java", "Digit Jawa" },
             { "bm", "Bambara" },
-            { "bn", metaValue_bn },
+            { "bn", "Benggali" },
             { "bo", metaValue_bo },
             { "dgr", "Dogrib" },
             { "br", "Breton" },
@@ -774,6 +798,7 @@ public class LocaleNames_ms extends OpenListResourceBundle {
             { "ses", "Koyraboro Senni" },
             { "ce", "Chechen" },
             { "ch", "Chamorro" },
+            { "%%REVISED", "Sistem Ejaan Semakan" },
             { "co", "Corsica" },
             { "Orya", "Oriya" },
             { "cs", "Czech" },
@@ -860,6 +885,7 @@ public class LocaleNames_ms extends OpenListResourceBundle {
             { "hy", metaValue_AM },
             { "hz", "Herero" },
             { "frc", "Perancis Cajun" },
+            { "%%FONIPA", "Fonetik IPA" },
             { "ia", "Interlingua" },
             { "Jamo", "Jamo" },
             { "id", metaValue_ID },
@@ -867,6 +893,7 @@ public class LocaleNames_ms extends OpenListResourceBundle {
             { "ie", "Interlingue" },
             { "ig", "Igbo" },
             { "ii", "Sichuan Yi" },
+            { "%%AO1990", "Perjanjian Sistem Ejaan Bahasa Portugis 1990" },
             { "io", "Ido" },
             { "is", metaValue_IS },
             { "it", metaValue_IT },
@@ -959,22 +986,26 @@ public class LocaleNames_ms extends OpenListResourceBundle {
             { "ny", "Nyanja" },
             { "kac", "Kachin" },
             { "kab", "Kabyle" },
+            { "%%POLYTON", "Banyak Nada" },
             { "oc", "Occitania" },
             { "kaj", "Jju" },
             { "kam", "Kamba" },
             { "men", metaValue_men },
+            { "%%EMODENG", "Inggeris Moden Awal" },
             { "mer", "Meru" },
             { "type.nu.armn", "Angka Armenia" },
             { "om", "Oromo" },
             { "or", "Odia" },
             { "Modi", "Modi" },
             { "os", "Ossete" },
+            { "%%ALALC97", "Perumian ALA-LC, edisi 1997" },
             { "bpy", "Bishnupriya" },
             { "kbd", "Kabardia" },
             { "mfe", "Morisyen" },
             { "srn", "Sranan Tongo" },
             { "pa", "Punjabi" },
             { "dua", "Duala" },
+            { "%%LIPAW", "Dialek Lipovaz Resia" },
             { "kbl", "Kanembu" },
             { "pl", metaValue_PL },
             { "type.nu.saur", "Digit Saurashtra" },
@@ -983,16 +1014,17 @@ public class LocaleNames_ms extends OpenListResourceBundle {
             { "pt", "Portugis" },
             { "key.co", "Tertib Isihan" },
             { "pt_BR", "Portugis Brazil" },
+            { "%%BOHORIC", "Abjad Bohoric" },
             { "kcg", "Tyap" },
             { "mgh", "Makhuwa-Meetto" },
-            { "key.cf", "Format Mata wang" },
+            { "key.cf", "Format Mata Wang" },
             { "type.nu.nkoo", "Digit N\u2019Ko" },
             { "key.ca", "Kalendar" },
             { "Laoo", "Lao" },
             { "mgo", "Meta\u2019" },
             { "type.hc.h23", "Sistem 24 Jam (0\u201323)" },
             { "type.hc.h24", "Sistem 24 Jam (1\u201324)" },
-            { "ssy", "Saho" },
+            { "ssy", metaValue_ssy },
             { "brh", "Brahui" },
             { "type.nu.mymr", "Digit Myammar" },
             { "qu", "Quechua" },
@@ -1006,6 +1038,7 @@ public class LocaleNames_ms extends OpenListResourceBundle {
             { "rn", "Rundi" },
             { "key.cu", "Mata wang" },
             { "ro", metaValue_RO },
+            { "%%SAAHO", metaValue_ssy },
             { "type.nu.orya", "Digit Oriya" },
             { "type.nu.hanidec", "Angka Perpuluhan Cina" },
             { "ru", metaValue_RU },
@@ -1017,6 +1050,7 @@ public class LocaleNames_ms extends OpenListResourceBundle {
             { "en_AU", "Inggeris Australia" },
             { "Dupl", "Trengkas Duployan" },
             { "sa", "Sanskrit" },
+            { "%%UCCOR", "Sistem Ejaan Bersatu" },
             { "sc", "Sardinia" },
             { "sd", "Sindhi" },
             { "se", "Sami Utara" },
@@ -1038,6 +1072,7 @@ public class LocaleNames_ms extends OpenListResourceBundle {
             { "Java", metaValue_jv },
             { "st", "Sotho Selatan" },
             { "su", metaValue_su },
+            { "%%NEDIS", "Dialek Natisone" },
             { "sv", metaValue_SE },
             { "sw", "Swahili" },
             { "type.nu.wcho", "Digit Wancho" },
@@ -1069,6 +1104,7 @@ public class LocaleNames_ms extends OpenListResourceBundle {
             { "tt", "Tatar" },
             { "tw", "Twi" },
             { "ty", "Tahiti" },
+            { "%%BISKE", "Dialek San Giorgio/Bila" },
             { "150", "Eropah" },
             { "151", "Eropah Timur" },
             { "type.nu.rohg", "Digit Hanifi Rohingya" },
@@ -1083,9 +1119,11 @@ public class LocaleNames_ms extends OpenListResourceBundle {
             { "uk", metaValue_UA },
             { "type.ca.coptic", "Kalendar Qibti" },
             { "ur", "Urdu" },
+            { "%%1994", "Sistem ejaan Resia standard" },
             { "xal", "Kalmyk" },
             { "uz", metaValue_UZ },
             { "kha", "Khasi" },
+            { "%%1996", "Sistem ejaan Jerman 1996" },
             { "nds_NL", "Saxon Rendah" },
             { "Sylo", "Syloti Nagri" },
             { "ve", "Venda" },
@@ -1094,6 +1132,7 @@ public class LocaleNames_ms extends OpenListResourceBundle {
             { "vi", metaValue_VN },
             { "khq", "Koyra Chiini" },
             { "key.hc", "Kitaran Jam (12 berbanding 24)" },
+            { "%%TARASK", "Sistem ejaan Taraskievica" },
             { "vo", "Volap\u00fck" },
             { "khw", "Khowar" },
             { "type.nu.mathsans", "Digit Matematik San Serif" },
@@ -1113,7 +1152,7 @@ public class LocaleNames_ms extends OpenListResourceBundle {
             { "wo", "Wolof" },
             { "zgh", "Tamazight Maghribi Standard" },
             { "ar_001", "Arab Standard Moden" },
-            { "Cans", "Cans" },
+            { "Cans", "Suku Kata Orang Asli Kanada Bersatu" },
             { "Mong", metaValue_MN },
             { "Hluw", "Hiroglif Anatoli" },
             { "gba", "Gbaya" },
@@ -1126,11 +1165,13 @@ public class LocaleNames_ms extends OpenListResourceBundle {
             { "type.nu.romanlow", "Angka Huruf Kecil Roman" },
             { "byn", "Blin" },
             { "Dogr", "Dogra" },
+            { "%%PAMAKA", "Dialek Pamaka" },
             { "Lyci", "Lycia" },
             { "byv", "Medumba" },
             { "gbz", "Zoroastrian Dari" },
             { "moh", "Mohawk" },
             { "kkj", "Kako" },
+            { "%%1694ACAD", "Awal Pertengahan Era Perancis" },
             { "Syrc", metaValue_SY },
             { "yi", "Yiddish" },
             { "mos", "Mossi" },
@@ -1147,6 +1188,7 @@ public class LocaleNames_ms extends OpenListResourceBundle {
             { "key.lb", "Gaya Pemisah Baris" },
             { "zu", "Zulu" },
             { "type.co.phonebook", "Aturan Isih Buku Telefon" },
+            { "%%MONOTON", "Ekanada" },
             { "Geor", metaValue_GE },
             { "Shrd", "Sharada" },
             { "kmb", "Kimbundu" },
@@ -1166,6 +1208,7 @@ public class LocaleNames_ms extends OpenListResourceBundle {
             { "koi", "Komi-Permyak" },
             { "Hung", "Hungary Lama" },
             { "kok", "Konkani" },
+            { "%%1901", "Sistem ejaan Jerman Tradisional" },
             { "type.nu.limb", "Digit Limbu" },
             { "zh_Hant", "Cina Tradisional" },
             { "Sund", metaValue_su },
@@ -1173,7 +1216,10 @@ public class LocaleNames_ms extends OpenListResourceBundle {
             { "type.nu.khmr", "Digit Khmer" },
             { "Tirh", "Tirhuta" },
             { "ilo", "Iloko" },
+            { "%%VALENCIA", "Valencia" },
             { "Cprt", "Cypriot" },
+            { "%%BAKU1926", "Abjad Latin Turki Disatukan" },
+            { "%%IJEKAVSK", "Fon Serbia dengan sebutan Ijekavia" },
             { "mua", "Mundang" },
             { "type.nu.guru", "Digit Gurmukhi" },
             { "mul", "Pelbagai Bahasa" },
@@ -1181,12 +1227,15 @@ public class LocaleNames_ms extends OpenListResourceBundle {
             { "mus", "Creek" },
             { "Glag", "Glagolitik" },
             { "gil", metaValue_KI },
+            { "%%KKCOR", "Sistem Ejaan Lazim" },
             { "Cher", metaValue_chr },
             { "cay", "Cayuga" },
             { "type.nu.tamldec", "Digit Tamil" },
             { "krc", "Karachay-Balkar" },
             { "inh", "Ingush" },
+            { "fa_AF", "Dari" },
             { "krl", "Karelian" },
+            { "%%OXENDICT", "Ejaan Kamus Inggeris Oxford" },
             { "efi", "Efik" },
             { "key.nu", "Nombor" },
             { "kru", "Kurukh" },
