@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -95,6 +91,7 @@ public class LocaleNames_nn extends OpenListResourceBundle {
         final String metaValue_tl = "tagalog";
         final String metaValue_ban = "balinesisk";
         final String metaValue_bug = "buginesisk";
+        final String metaValue_ccp = "chakma";
         final String metaValue_chr = "cherokee";
         final String metaValue_cop = "koptisk";
         final String metaValue_got = "gotisk";
@@ -115,6 +112,7 @@ public class LocaleNames_nn extends OpenListResourceBundle {
             { "Tagb", "tagbanwa" },
             { "Zsye", "emoji" },
             { "%%NJIVA", "gniva- og njivadialekt" },
+            { "ccp", metaValue_ccp },
             { "egy", "gammalegyptisk" },
             { "raj", "rajasthani" },
             { "Phag", "phags-pa" },
@@ -243,7 +241,7 @@ public class LocaleNames_nn extends OpenListResourceBundle {
             { "ER", "Eritrea" },
             { "ES", "Spania" },
             { "ET", "Etiopia" },
-            { "EU", "EU" },
+            { "EU", "Den europeiske unionen" },
             { "elx", "elamite" },
             { "type.ca.gregorian", "gregoriansk kalender" },
             { "EZ", "eurosona" },
@@ -282,7 +280,7 @@ public class LocaleNames_nn extends OpenListResourceBundle {
             { "GP", "Guadeloupe" },
             { "GQ", "Ekvatorial-Guinea" },
             { "GR", "Hellas" },
-            { "GS", "S\u00f8r-Georgia og S\u00f8r-Sandwich\u00f8yene" },
+            { "GS", "S\u00f8r-Georgia og S\u00f8r-Sandwich\u00f8yane" },
             { "GT", "Guatemala" },
             { "GU", "Guam" },
             { "GW", "Guinea-Bissau" },
@@ -293,7 +291,7 @@ public class LocaleNames_nn extends OpenListResourceBundle {
             { "ckb", "sorani" },
             { "zxx", "utan spr\u00e5kleg innhald" },
             { "Vaii", metaValue_vai },
-            { "HK", "Hongkong S.A.R. Kina" },
+            { "HK", "Hongkong SAR Kina" },
             { "HM", "Heard\u00f8ya og McDonald\u00f8yane" },
             { "HN", "Honduras" },
             { "HR", "Kroatia" },
@@ -312,7 +310,7 @@ public class LocaleNames_nn extends OpenListResourceBundle {
             { "IL", "Israel" },
             { "IM", "Man" },
             { "IN", "India" },
-            { "IO", "Det britiske territoriet I Indiahavet" },
+            { "IO", "Det britiske territoriet i Indiahavet" },
             { "IQ", "Irak" },
             { "IR", "Iran" },
             { "IS", "Island" },
@@ -379,7 +377,7 @@ public class LocaleNames_nn extends OpenListResourceBundle {
             { "MC", "Monaco" },
             { "MD", "Moldova" },
             { "ME", "Montenegro" },
-            { "MF", "Saint Martin" },
+            { "MF", "Saint-Martin" },
             { "lam", "lamba" },
             { "MG", "Madagaskar" },
             { "Thai", metaValue_th },
@@ -390,7 +388,7 @@ public class LocaleNames_nn extends OpenListResourceBundle {
             { "MM", "Myanmar (Burma)" },
             { "MN", "Mongolia" },
             { "new", "newari" },
-            { "MO", "Macao S.A.R. Kina" },
+            { "MO", "Macao SAR Kina" },
             { "MP", "Nord-Marianane" },
             { "MQ", "Martinique" },
             { "MR", "Mauritania" },
@@ -406,6 +404,7 @@ public class LocaleNames_nn extends OpenListResourceBundle {
             { "MZ", "Mosambik" },
             { "Phli", "inskripsjonspahlavi" },
             { "NA", "Namibia" },
+            { "202", "Afrika s\u00f8r for Sahara" },
             { "type.ca.hebrew", "hebraisk kalender" },
             { "NC", "Ny-Caledonia" },
             { "NE", "Niger" },
@@ -435,7 +434,6 @@ public class LocaleNames_nn extends OpenListResourceBundle {
             { "PA", "Panama" },
             { "type.ca.islamic-civil", "islamsk sivil kalender" },
             { "csb", "kasjubisk" },
-            { "en_GB", "britisk engelsk" },
             { "PE", "Peru" },
             { "PF", "Fransk Polynesia" },
             { "PG", "Papua Ny-Guinea" },
@@ -447,7 +445,7 @@ public class LocaleNames_nn extends OpenListResourceBundle {
             { "PN", "Pitcairn" },
             { "PR", "Puerto Rico" },
             { "Bali", metaValue_ban },
-            { "PS", "Palestinsk territorium" },
+            { "PS", "Det palestinske omr\u00e5det" },
             { "PT", "Portugal" },
             { "PW", "Palau" },
             { "nia", "nias" },
@@ -514,13 +512,13 @@ public class LocaleNames_nn extends OpenListResourceBundle {
             { "SX", "Sint Maarten" },
             { "SY", "Syria" },
             { "yao", "yao" },
-            { "SZ", "Swaziland" },
+            { "SZ", "Eswatini" },
             { "arw", "arawak" },
             { "yap", "yapesisk" },
             { "TA", "Tristan da Cunha" },
             { "asa", "asu (Tanzania)" },
             { "type.ms.ussystem", "amerikansk m\u00e5lesystem" },
-            { "021", "nordlege Amerika" },
+            { "021", "Nordlege Amerika" },
             { "TC", "Turks- og Caicos\u00f8yane" },
             { "yav", "yangben" },
             { "TD", "Tsjad" },
@@ -530,7 +528,7 @@ public class LocaleNames_nn extends OpenListResourceBundle {
             { "TJ", "Tadsjikistan" },
             { "029", "Karibia" },
             { "TK", "Tokelau" },
-            { "TL", "Timor-Leste (Aust-Timor)" },
+            { "TL", "Aust-Timor" },
             { "ybb", "yemba" },
             { "TM", "Turkmenistan" },
             { "%%BOONT", "boontling" },
@@ -590,7 +588,9 @@ public class LocaleNames_nn extends OpenListResourceBundle {
             { "WS", "Samoa" },
             { "wal", "wolaytta" },
             { "was", "washo" },
+            { "XA", "pseudospr\u00e5k \u2013 aksentar" },
             { "war", "waray" },
+            { "XB", "pseudospr\u00e5k \u2013 RTL" },
             { "awa", "avadhi" },
             { "061", "Polynesia" },
             { "XK", "Kosovo" },
@@ -709,7 +709,7 @@ public class LocaleNames_nn extends OpenListResourceBundle {
             { "Nkoo", metaValue_nqo },
             { "sel", "selkupisk" },
             { "ca", "katalansk" },
-            { "ses", "Koyraboro Senni" },
+            { "ses", "koyraboro senni" },
             { "ce", "tsjetsjensk" },
             { "ch", "chamorro" },
             { "%%REVISED", "revidert rettskriving" },
@@ -745,7 +745,7 @@ public class LocaleNames_nn extends OpenListResourceBundle {
             { "type.co.big5han", "tradisjonell kinesisk sortering" },
             { "es", "spansk" },
             { "et", "estisk" },
-            { "Hanb", "han med bopomofo" },
+            { "Hanb", "hanb" },
             { "eu", "baskisk" },
             { "Buhd", "buhid" },
             { "Hang", "hangul" },
@@ -771,7 +771,7 @@ public class LocaleNames_nn extends OpenListResourceBundle {
             { "fy", "vestfrisisk" },
             { "ga", "irsk" },
             { "gd", "skotsk-g\u00e6lisk" },
-            { "gl", "galicisk" },
+            { "gl", "galisisk" },
             { "gn", "guarani" },
             { "bho", "bhojpuri" },
             { "und", "ukjent spr\u00e5k" },
@@ -877,13 +877,13 @@ public class LocaleNames_nn extends OpenListResourceBundle {
             { "Armi", "armisk" },
             { "na", "nauru" },
             { "type.co.search", "generelt s\u00f8k" },
-            { "nb", "bokm\u00e5l" },
+            { "nb", "norsk bokm\u00e5l" },
             { "nd", "nord-ndebele" },
             { "ne", "nepalsk" },
             { "ng", "ndonga" },
             { "mdr", "mandar" },
             { "nl", "nederlandsk" },
-            { "nn", "nynorsk" },
+            { "nn", "norsk nynorsk" },
             { "no", "norsk" },
             { "nr", "s\u00f8r-ndebele" },
             { "nv", "navajo" },
@@ -919,7 +919,7 @@ public class LocaleNames_nn extends OpenListResourceBundle {
             { "mga", "mellomirsk" },
             { "key.co", "sorteringsrekkjef\u00f8lgje" },
             { "kcg", "tyap" },
-            { "mgh", "Makhuwa-Meetto" },
+            { "mgh", "makhuwa-meetto" },
             { "key.cf", "valutaformat" },
             { "bra", "braj" },
             { "key.ca", "kalender" },
@@ -998,9 +998,9 @@ public class LocaleNames_nn extends OpenListResourceBundle {
             { "dyo", "jola-fonyi" },
             { "type.nu.jpan", "japanske tal" },
             { "tr", "tyrkisk" },
+            { "Cakm", metaValue_ccp },
             { "ts", "tsonga" },
             { "swb", "shimaore" },
-            { "Cakm", "chakma" },
             { "tt", "tatarisk" },
             { "dyu", "dyula" },
             { "tw", "twi" },
@@ -1026,7 +1026,7 @@ public class LocaleNames_nn extends OpenListResourceBundle {
             { "nds_NL", "l\u00e5gsaksisk" },
             { "Sylo", "syloti nagri" },
             { "ve", "venda" },
-            { "type.ca.roc", "kalender for Republikken Kina" },
+            { "type.ca.roc", "minguo-kalender" },
             { "vi", "vietnamesisk" },
             { "kho", "khotanesisk" },
             { "khq", "koyra chiini" },
@@ -1122,6 +1122,7 @@ public class LocaleNames_nn extends OpenListResourceBundle {
             { "type.nu.tamldec", "tamilske siffer" },
             { "krc", "karachay-balkar" },
             { "inh", "ingusjisk" },
+            { "fa_AF", "dari" },
             { "krl", "karelsk" },
             { "efi", "efik" },
             { "key.nu", "tal" },
