@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -143,7 +139,7 @@ public class LocaleNames_sl extends OpenListResourceBundle {
             { "CA", "Kanada" },
             { "CC", "Kokosovi otoki" },
             { "CD", "Demokrati\u010dna republika Kongo" },
-            { "CF", "Centralnoafri\u0161ka republika" },
+            { "CF", "Srednjeafri\u0161ka republika" },
             { "CG", "Kongo - Brazzaville" },
             { "CH", "\u0160vica" },
             { "CI", "Slonoko\u0161\u010dena obala" },
@@ -202,7 +198,7 @@ public class LocaleNames_sl extends OpenListResourceBundle {
             { "GU", "Guam" },
             { "GW", "Gvineja Bissau" },
             { "GY", "Gvajana" },
-            { "HK", "Posebno administrativno obmo\u010dje LR Kitajske Hongkong" },
+            { "HK", "Posebno upravno obmo\u010dje Ljudske republike Kitajske Hongkong" },
             { "HM", "Heardov otok in McDonaldovi otoki" },
             { "HN", "Honduras" },
             { "HR", "Hrva\u0161ka" },
@@ -256,7 +252,7 @@ public class LocaleNames_sl extends OpenListResourceBundle {
             { "ML", "Mali" },
             { "MM", "Mjanmar (Burma)" },
             { "MN", "Mongolija" },
-            { "MO", "Posebno administrativno obmo\u010dje LR Kitajske Macao" },
+            { "MO", "Posebno upravno obmo\u010dje Ljudske republike Kitajske Macao" },
             { "MP", "Severni Marianski otoki" },
             { "MQ", "Martinik" },
             { "MR", "Mavretanija" },
@@ -421,7 +417,7 @@ public class LocaleNames_sl extends OpenListResourceBundle {
             { "gv", "man\u0161\u010dina" },
             { "ha", "hav\u0161\u010dina" },
             { "he", "hebrej\u0161\u010dina" },
-            { "hi", "hinduj\u0161\u010dina" },
+            { "hi", "hindij\u0161\u010dina" },
             { "ho", "hiri motu" },
             { "hr", "hrva\u0161\u010dina" },
             { "ht", "haitijska kreol\u0161\u010dina" },
@@ -464,7 +460,7 @@ public class LocaleNames_sl extends OpenListResourceBundle {
             { "lt", "litov\u0161\u010dina" },
             { "lu", "luba-katanga" },
             { "lv", "latvij\u0161\u010dina" },
-            { "mg", "malaga\u0161\u010dina" },
+            { "mg", "malga\u0161\u010dina" },
             { "mh", "marshallov\u0161\u010dina" },
             { "mi", "maor\u0161\u010dina" },
             { "mk", "makedon\u0161\u010dina" },
@@ -540,7 +536,7 @@ public class LocaleNames_sl extends OpenListResourceBundle {
             { "uz", "uzbe\u0161\u010dina" },
             { "ve", "venda" },
             { "vi", "vietnam\u0161\u010dina" },
-            { "vo", "volapuk" },
+            { "vo", "volapik" },
             { "wa", "valon\u0161\u010dina" },
             { "wo", "volof\u0161\u010dina" },
             { "xh", "ko\u0161\u010dina" },
@@ -867,7 +863,6 @@ public class LocaleNames_sl extends OpenListResourceBundle {
             { "Bugi", "buginski" },
             { "Buhd", "buhidski" },
             { "Cans", "poenotena zlogovna pisava kanadskih staroselcev" },
-            { "Cham", "Cham" },
             { "Cher", "\u010deroke\u0161ki" },
             { "Cirt", "kirt" },
             { "Copt", "koptski" },
@@ -887,12 +882,12 @@ public class LocaleNames_sl extends OpenListResourceBundle {
             { "Grek", "gr\u0161ki" },
             { "Gujr", "gud\u017earatski" },
             { "Guru", "gurmuki" },
-            { "Hanb", "Han + Bopomofo" },
+            { "Hanb", "han + bopomofo" },
             { "Hang", "hangul" },
             { "Hani", "kanji" },
             { "Hano", "hanunski" },
-            { "Hans", "poenostavljena pisava han" },
-            { "Hant", "tradicionalna pisava han" },
+            { "Hans", "poenostavljena pisava" },
+            { "Hant", "tradicionalna pisava" },
             { "Hebr", "hebrejski" },
             { "Hira", "hiragana" },
             { "Hmng", "pahavhmonska zlogovna pisava" },
@@ -900,7 +895,7 @@ public class LocaleNames_sl extends OpenListResourceBundle {
             { "Hung", "staroogrski" },
             { "Inds", "indu\u0161ki" },
             { "Ital", "staroitalski" },
-            { "Jamo", "Jamo" },
+            { "Jamo", "jamo" },
             { "Java", "javanski" },
             { "Jpan", "japonski" },
             { "Kali", "karenski" },
@@ -981,10 +976,11 @@ public class LocaleNames_sl extends OpenListResourceBundle {
             { "de_CH", "visoka nem\u0161\u010dina (\u0160vica)" },
             { "en_AU", "avstralska angle\u0161\u010dina" },
             { "en_CA", "kanadska angle\u0161\u010dina" },
-            { "en_GB", "angle\u0161\u010dina (VB)" },
-            { "en_US", "angle\u0161\u010dina (ZDA)" },
+            { "en_GB", "britanska angle\u0161\u010dina" },
+            { "en_US", "ameri\u0161ka angle\u0161\u010dina" },
             { "es_ES", "evropska \u0161pan\u0161\u010dina" },
             { "es_MX", "mehi\u0161ka \u0161pan\u0161\u010dina" },
+            { "fa_AF", "darij\u0161\u010dina" },
             { "fr_CA", "kanadska franco\u0161\u010dina" },
             { "fr_CH", "\u0161vicarska franco\u0161\u010dina" },
             { "nl_BE", "flam\u0161\u010dina" },
@@ -996,6 +992,7 @@ public class LocaleNames_sl extends OpenListResourceBundle {
             { "%%1994", "standardizirani rezijanski pravopis (1994)" },
             { "%%1996", "novi nem\u0161ki pravopis (1996)" },
             { "ar_001", "sodobna standardna arab\u0161\u010dina" },
+            { "es_419", "latinskoameri\u0161ka \u0161pan\u0161\u010dina" },
             { "key.ca", "koledar" },
             { "key.cf", "oblika zapisa valute" },
             { "key.co", "razvr\u0161\u010danje" },
